searchData={"items":[{"type":"module","title":"EXGBoost","doc":"Elixir bindings for the XGBoost library. `EXGBoost` provides an implementation of XGBoost that works with\n[Nx](https://hexdocs.pm/nx/Nx.html) tensors.\n\nXtreme Gradient Boosting (XGBoost) is an optimized distributed gradient\nboosting library designed to be highly efficient, flexible and portable.\nIt implements machine learning algorithms under the [Gradient Boosting](https://en.wikipedia.org/wiki/Gradient_boosting)\nframework. XGBoost provides a parallel tree boosting (also known as GBDT, GBM)\nthat solve many data science problems in a fast and accurate way. The same code\nruns on major distributed environment (Hadoop, SGE, MPI) and can solve problems beyond\nbillions of examples.","ref":"EXGBoost.html"},{"type":"module","title":"Installation - EXGBoost","doc":"```elixir\ndef deps do\n[\n  {:exgboost, \"~> 0.5\"}\n]\nend\n```","ref":"EXGBoost.html#module-installation"},{"type":"module","title":"API Data Structures - EXGBoost","doc":"EXGBoost's top-level `EXGBoost` API works directly and only with `Nx.Tensor` for data\nrepresentation and with `EXGBoost.Booster` structs as an internal representation.\nDirect manipulation of `EXGBoost.Booster` structs is discouraged.","ref":"EXGBoost.html#module-api-data-structures"},{"type":"module","title":"Basic Usage - EXGBoost","doc":"key = Nx.Random.key(42)\n    {x, key} = Nx.Random.normal(key, 0, 1, shape: {10, 5})\n    {y, key} = Nx.Random.normal(key, 0, 1, shape: {10})\n    model = EXGBoost.train(x, y)\n    EXGBoost.predict(model, x)","ref":"EXGBoost.html#module-basic-usage"},{"type":"module","title":"Training - EXGBoost","doc":"EXGBoost is designed to feel familiar to users of the Python XGBoost library. `EXGBoost.train/2` is the\nprimary entry point for training a model. It accepts an Nx tensor for the features and an Nx tensor for the labels.\n`EXGBoost.train/2` returns a trained `EXGBoost.Booster` struct that can be used for prediction. `EXGBoost.train/2` also\naccepts a keyword list of options that can be used to configure the training process. See the\n[XGBoost documentation](https://xgboost.readthedocs.io/en/latest/parameter.html) for the full list of options.\n\n`EXGBoost.train/2` has the ability for the user to provide a custom training function that will be used to train the model.\nThis is done by passing a function to the `:obj` option. See `EXGBoost.Booster.update/4` for more information on this.\n\nAnother feature of `EXGBoost.train/2` is the ability to provide a validation set for early stopping. This is done\nby passing a list of 3-tuples to the `:evals` option. Each 3-tuple should contain an Nx tensor for the features, an Nx tensor\nfor the labels, and a string label for the validation set name. The validation set will be used to calculate the validation\nerror at each iteration of the training process. If the validation error does not improve for `:early_stopping_rounds` iterations\nthen the training process will stop. See the [XGBoost documentation](https://xgboost.readthedocs.io/en/latest/tutorials/param_tuning.html)\nfor a more detailed explanation of early stopping.\n\nEarly stopping is achieved through the use of callbacks. `EXGBoost.train/2` accepts a list of callbacks that will be called\nat each iteration of the training process. The callbacks can be used to implement custom logic. For example, the user could\nimplement a callback that will print the validation error at each iteration of the training process or to provide a custom\nsetup function for training. See`EXGBoost.Training.Callback` for more information on callbacks.\n\nPlease notes that callbacks are called in the order that they are provided. If you provide multiple callbacks that modify\nthe same parameter then the last callback will trump the previous callbacks. For example, if you provide a callback that\nsets the `:early_stopping_rounds` parameter to 10 and then provide a callback that sets the `:early_stopping_rounds` parameter\nto 20 then the `:early_stopping_rounds` parameter will be set to 20.\n\nYou are also able to pass parameters to be applied to the Booster model using the `:params` option. These parameters will\nbe applied to the Booster model before training begins. This allows you to set parameters that are not available as options\nto `EXGBoost.train/2`. See the [XGBoost documentation](https://xgboost.readthedocs.io/en/latest/parameter.html) for a full\nlist of parameters.\n\n    EXGBoost.train(\n      x,\n      y,\n      obj: :multi_softprob,\n      evals: [{x_test, y_test, \"test\"}],\n      learning_rates: fn i -> i / 10 end,\n      num_boost_round: 10,\n      early_stopping_rounds: 3,\n      max_depth: 3,\n      eval_metric: [:rmse, :logloss]\n    )","ref":"EXGBoost.html#module-training"},{"type":"module","title":"Prediction - EXGBoost","doc":"`EXGBoost.predict/2` is the primary entry point for making predictions with a trained model.\nIt accepts an `EXGBoost.Booster` struct (which is the output of `EXGBoost.train/2`).\n`EXGBoost.predict/2` returns an Nx tensor containing the predictions and also accepts\na keyword list of options that can be used to configure the prediction process.\n\n\n```elixir\npreds = EXGBoost.train(X, y) |> EXGBoost.predict(X)\n```","ref":"EXGBoost.html#module-prediction"},{"type":"module","title":"Serialization - EXGBoost","doc":"A Booster can be serialized to a file using `EXGBoost.write_*` and loaded from a file\nusing `EXGBoost.read_*`. The file format can be specified using the `:format` option\nwhich can be either `:json` or `:ubj`. The default is `:json`. If the file already exists, it will NOT\nbe overwritten by default.  Boosters can either be serialized to a file or to a binary string.\nBoosters can be serialized in three different ways: configuration only, configuration and model, or\nmodel only. `dump` functions will serialize the Booster to a binary string.\nFunctions named with `weights` will serialize the model's trained parameters only. This is best used when the model\nis already trained and only inferences/predictions are going to be performed. Functions named with `config` will\nserialize the configuration only. Functions that specify `model` will serialize both the model parameters\nand the configuration.\n\n#","ref":"EXGBoost.html#module-serialization"},{"type":"module","title":"Output Formats - EXGBoost","doc":"- `read`/`write` -  File.\n- `load`/`dump` - Binary buffer.\n\n#","ref":"EXGBoost.html#module-output-formats"},{"type":"module","title":"Output Contents - EXGBoost","doc":"- `config` - Save the configuration only.\n- `weights` - Save the model parameters only. Use this when you want to save the model to a format that can be ingested by other XGBoost APIs.\n- `model` - Save both the model parameters and the configuration.","ref":"EXGBoost.html#module-output-contents"},{"type":"module","title":"Plotting - EXGBoost","doc":"`EXGBoost.plot_tree/2` is the primary entry point for plotting a tree from a trained model.\nIt accepts an `EXGBoost.Booster` struct (which is the output of `EXGBoost.train/2`).\n`EXGBoost.plot_tree/2` returns a VegaLite spec that can be rendered in a notebook or saved to a file.\n`EXGBoost.plot_tree/2` also accepts a keyword list of options that can be used to configure the plotting process.\n\nSee `EXGBoost.Plotting` for more detail on plotting.\n\nYou can see available styles by running `EXGBoost.Plotting.get_styles()` or refer to the `EXGBoost.Plotting.Styles`\ndocumentation for a gallery of the styles.","ref":"EXGBoost.html#module-plotting"},{"type":"module","title":"Kino & Livebook Integration - EXGBoost","doc":"`EXGBoost` integrates with [Kino](https://hexdocs.pm/kino/Kino.html) and [Livebook](https://livebook.dev/)\nto provide a rich interactive experience for data scientists.\n\nEXGBoost implements the `Kino.Render` protocol for `EXGBoost.Booster` structs. This allows you to render\na Booster in a Livebook notebook.  Under the hood, `EXGBoost` uses [Vega-Lite](https://vega.github.io/vega-lite/)\nand [Kino Vega-Lite](https://hexdocs.pm/kino_vega_lite/Kino.VegaLite.html) to render the Booster.\n\nSee the [`Plotting in EXGBoost`](notebooks/plotting.livemd) Notebook for an example of how to use `EXGBoost` with `Kino` and `Livebook`.","ref":"EXGBoost.html#module-kino-livebook-integration"},{"type":"module","title":"Examples - EXGBoost","doc":"See the example Notebooks in the left sidebar (under the `Pages` tab) for more examples and tutorials\non how to use EXGBoost.","ref":"EXGBoost.html#module-examples"},{"type":"function","title":"EXGBoost.dump_config/2","doc":"Dump a model config to a buffer as a JSON - encoded string.","ref":"EXGBoost.html#dump_config/2"},{"type":"function","title":"Options - EXGBoost.dump_config/2","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.","ref":"EXGBoost.html#dump_config/2-options"},{"type":"function","title":"EXGBoost.dump_model/2","doc":"Dump a model to a binary encoded in the desired format.","ref":"EXGBoost.html#dump_model/2"},{"type":"function","title":"Options - EXGBoost.dump_model/2","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.","ref":"EXGBoost.html#dump_model/2-options"},{"type":"function","title":"EXGBoost.dump_weights/2","doc":"Dump a model's trained parameters to a buffer as a JSON-encoded binary.","ref":"EXGBoost.html#dump_weights/2"},{"type":"function","title":"Options - EXGBoost.dump_weights/2","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.","ref":"EXGBoost.html#dump_weights/2-options"},{"type":"function","title":"EXGBoost.get_config/0","doc":"Get current values of the global configuration.\n\nGlobal configuration consists of a collection of parameters that can be\napplied in the global scope. See `Global Parameters` in `EXGBoost.Parameters`\nfor the full list of parameters supported in the global configuration.","ref":"EXGBoost.html#get_config/0"},{"type":"function","title":"EXGBoost.inplace_predict/3","doc":"Run prediction in-place, Unlike `EXGBoost.predict/2`, in-place prediction does not cache the prediction result.","ref":"EXGBoost.html#inplace_predict/3"},{"type":"function","title":"Options - EXGBoost.inplace_predict/3","doc":"* `:base_margin` -  Base margin used for boosting from existing model.\n\n* `:missing` - Value used for missing values. If None, defaults to `Nx.Constants.nan()`.\n\n* `:predict_type` - One of:\n\n  * `\"value\"`  - Output model prediction values.\n\n  * `\"margin\"`  - Output the raw untransformed margin value.\n\n* `:output_margin` - Whether to output the raw untransformed margin value.\n\n* `:iteration_range` - See `EXGBoost.predict/2` for details.\n\n* `:strict_shape` - See `EXGBoost.predict/2` for details.\n\nReturns an Nx.Tensor containing the predictions.","ref":"EXGBoost.html#inplace_predict/3-options"},{"type":"function","title":"EXGBoost.load_config/2","doc":"Create a new Booster from a config buffer. The config buffer must be from the output of `dump_config/2`.","ref":"EXGBoost.html#load_config/2"},{"type":"function","title":"Options - EXGBoost.load_config/2","doc":"* `:booster` (struct of type EXGBoost.Booster) - The Booster to load the model into. If a Booster is provided, the model will be loaded into\n  that Booster. Otherwise, a new Booster will be created. If a Booster is provided, model parameters\n  will be merged with the existing Booster's parameters using Map.merge/2, where the parameters\n  of the provided Booster take precedence.","ref":"EXGBoost.html#load_config/2-options"},{"type":"function","title":"EXGBoost.load_model/1","doc":"Read a model from a buffer and return the Booster.","ref":"EXGBoost.html#load_model/1"},{"type":"function","title":"EXGBoost.load_weights/1","doc":"Read a model's trained parameters from a buffer and return the Booster.","ref":"EXGBoost.html#load_weights/1"},{"type":"function","title":"EXGBoost.plot_tree/2","doc":"Plot a tree from a Booster model and save it to a file.","ref":"EXGBoost.html#plot_tree/2"},{"type":"function","title":"Options - EXGBoost.plot_tree/2","doc":"* `:format` - the format to export the graphic as, must be either of: `:json`, `:html`, `:png`, `:svg`, `:pdf`. By default the format is inferred from the file extension.\n* `:local_npm_prefix` - a relative path pointing to a local npm project directory where the necessary npm packages are installed. For instance, in Phoenix projects you may want to pass local_npm_prefix: \"assets\". By default the npm packages are searched for in the current directory and globally.\n* `:path` - the path to save the graphic to. If not provided, the graphic is returned as a VegaLite spec.\n* `:opts` - additional options to pass to `EXGBoost.Plotting.plot/2`. See `EXGBoost.Plotting` for more information.","ref":"EXGBoost.html#plot_tree/2-options"},{"type":"function","title":"EXGBoost.predict/3","doc":"Predict with a booster model against a tensor.\n\nThe full model will be used unless `iteration_range` is specified,\nmeaning user have to either slice the model or use the `best_iteration`\nattribute to get prediction from best model returned from early stopping.","ref":"EXGBoost.html#predict/3"},{"type":"function","title":"Options - EXGBoost.predict/3","doc":"* `:output_margin` - Whether to output the raw untransformed margin value.\n\n* `:pred_leaf ` - When this option is on, the output will be an `Nx.Tensor` of\n    shape {nsamples, ntrees}, where each row indicates the predicted leaf\n    index of each sample in each tree. Note that the leaf index of a tree is\n    unique per tree, but not globally, so you may find leaf 1 in both tree 1 and tree 0.\n\n* `:pred_contribs` - When this is `true` the output will be a matrix of size `{nsample,\n    nfeats + 1}` with each record indicating the feature contributions\n    (SHAP values) for that prediction. The sum of all feature\n    contributions is equal to the raw untransformed margin value of the\n    prediction. Note the final column is the bias term.\n\n* `:approx_contribs` - Approximate the contributions of each feature.  Used when `pred_contribs` or\n    `pred_interactions` is set to `true`.  Changing the default of this parameter\n    (false) is not recommended.\n\n* `:pred_interactions` - When this is `true` the output will be an `Nx.Tensor` of shape\n    {nsamples, nfeats + 1} indicating the SHAP interaction values for\n    each pair of features. The sum of each row (or column) of the\n    interaction values equals the corresponding SHAP value (from\n    pred_contribs), and the sum of the entire matrix equals the raw\n    untransformed margin value of the prediction. Note the last row and\n    column correspond to the bias term.\n\n* `:validate_features` - When this is `true`, validate that the Booster's and data's\n    feature_names are identical. Otherwise, it is assumed that the\n    feature_names are the same.\n\n* `:training` - Determines whether the prediction value is used for training. This\n    can affect the `dart` booster, which performs dropouts during training iterations\n    but uses all trees for inference. If you want to obtain result with dropouts, set\n    this option to `true`. Also, the option is set to `true` when obtaining prediction for\n    custom objective function.\n\n* `:iteration_range` - Specifies which layer of trees are used in prediction. For example, if a\n    random forest is trained with 100 rounds. Specifying `iteration_range=(10,\n    20)`, then only the forests built during [10, 20) (half open set) rounds are\n    used in this prediction.\n\n* `:strict_shape` - When set to `true`, output shape is invariant to whether classification is used.\n    For both value and margin prediction, the output shape is (n_samples,\n    n_groups), n_groups == 1 when multi-class is not used. Defaults to `false`, in\n    which case the output shape can be (n_samples, ) if multi-class is not used.\n\nReturns an Nx.Tensor containing the predictions.","ref":"EXGBoost.html#predict/3-options"},{"type":"function","title":"EXGBoost.read_config/2","doc":"Create a new Booster from a config file. The config file must be from the output of `write_config/2`.","ref":"EXGBoost.html#read_config/2"},{"type":"function","title":"Options - EXGBoost.read_config/2","doc":"* `:booster` (struct of type EXGBoost.Booster) - The Booster to load the model into. If a Booster is provided, the model will be loaded into\n  that Booster. Otherwise, a new Booster will be created. If a Booster is provided, model parameters\n  will be merged with the existing Booster's parameters using Map.merge/2, where the parameters\n  of the provided Booster take precedence.","ref":"EXGBoost.html#read_config/2-options"},{"type":"function","title":"EXGBoost.read_model/1","doc":"Read a model from a file and return the Booster.","ref":"EXGBoost.html#read_model/1"},{"type":"function","title":"EXGBoost.read_weights/1","doc":"Read a model's trained parameters from a file and return the Booster.","ref":"EXGBoost.html#read_weights/1"},{"type":"function","title":"EXGBoost.set_config/1","doc":"Set global configuration.\n\nGlobal configuration consists of a collection of parameters that can be\napplied in the global scope. See `Global Parameters` in `EXGBoost.Parameters`\nfor the full list of parameters supported in the global configuration.","ref":"EXGBoost.html#set_config/1"},{"type":"function","title":"EXGBoost.train/3","doc":"Train a new booster model given a data tensor and a label tensor.","ref":"EXGBoost.html#train/3"},{"type":"function","title":"Options - EXGBoost.train/3","doc":"* `:obj` - Specify the learning task and the corresponding learning objective.\n  This function must accept two arguments: preds, dtrain. preds is an array of\n  predicted real valued scores. dtrain is the training data set. This function\n  returns gradient and second order gradient.\n\n* `:num_boost_rounds` - Number of boosting iterations.\n\n* `:evals` - A list of 3-Tuples `{x, y, label}` to use as a validation set for\n  early-stopping.\n\n* `:early_stopping_rounds` - Activates early stopping. Target metric needs to\n  increase/decrease (depending on metric) at least every `early_stopping_rounds`\n  round(s) to continue training. Requires at least one item in `:evals`. If there's\n  more than one, will use the last eval set. If there’s more than one metric in the\n  `eval_metric` parameter given in the booster's params, the last metric will be\n  used for early stopping. If early stopping occurs, the model will have two additional fields:\n\n\n    - `bst.best_score`\n    - `bst.best_iteration`.\n\n  If these values are `nil` then no early stopping occurred.\n\n* `:verbose_eval` - Requires at least one item in `evals`. If `verbose_eval` is true then the evaluation metric on the validation set is printed at each boosting stage. If verbose_eval is an\n    integer then the evaluation metric on the validation set is printed at every given `verbose_eval` boosting stage. The last boosting stage / the boosting stage found by using `early_stopping_rounds`\n    is also printed. Example: with `verbose_eval=4` and at least one item in evals, an evaluation metric is printed every 4 boosting stages, instead of every boosting stage.\n\n* `:learning_rates` - Either an arity 1 function that accept an integer parameter epoch and returns the corresponding learning rate or a list with the same length as num_boost_rounds.\n\n* `:callbacks` - List of `EXGBoost.Training.Callback` that are called during a given event. It is possible to use predefined callbacks by using `EXGBoost.Training.Callback` module.\n    Callbacks should be in the form of a keyword list where the only valid keys are `:before_training`, `:after_training`, `:before_iteration`, and `:after_iteration`.\n    The value of each key should be a list of functions that accepts a booster and an iteration and returns a booster. The function will be called at the appropriate time with the booster and the iteration\n    as the arguments. The function should return the booster. If the function returns a booster with a different memory address, the original booster will be replaced with the new booster.\n    If the function returns the original booster, the original booster will be used. If the function returns a booster with the same memory address but different contents, the behavior is undefined.\n\n\n* `opts` - Refer to `EXGBoost.Parameters` for the full list of options.","ref":"EXGBoost.html#train/3-options"},{"type":"function","title":"EXGBoost.write_config/3","doc":"Write a model config to a file as a JSON - encoded string.","ref":"EXGBoost.html#write_config/3"},{"type":"function","title":"Options - EXGBoost.write_config/3","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.\n\n* `:overwrite` (`t:boolean/0`) - Whether or not to overwrite the file if it already exists. The default value is `false`.","ref":"EXGBoost.html#write_config/3-options"},{"type":"function","title":"EXGBoost.write_model/3","doc":"Write a model to a file.","ref":"EXGBoost.html#write_model/3"},{"type":"function","title":"Options - EXGBoost.write_model/3","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.\n\n* `:overwrite` (`t:boolean/0`) - Whether or not to overwrite the file if it already exists. The default value is `false`.","ref":"EXGBoost.html#write_model/3-options"},{"type":"function","title":"EXGBoost.write_weights/3","doc":"Write a model's trained parameters to a file.","ref":"EXGBoost.html#write_weights/3"},{"type":"function","title":"Options - EXGBoost.write_weights/3","doc":"* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.\n\n* `:overwrite` (`t:boolean/0`) - Whether or not to overwrite the file if it already exists. The default value is `false`.","ref":"EXGBoost.html#write_weights/3-options"},{"type":"function","title":"EXGBoost.xgboost_build_info/0","doc":"Check the build information of the xgboost library.\n\nReturns a map containing information about the build.","ref":"EXGBoost.html#xgboost_build_info/0"},{"type":"function","title":"EXGBoost.xgboost_version/0","doc":"Check the version of the xgboost library.\n\nReturns a 3-tuple in the form of `{major, minor, patch}`.","ref":"EXGBoost.html#xgboost_version/0"},{"type":"module","title":"EXGBoost.Plotting","doc":"Functions for plotting EXGBoost `Booster` models using [Vega](https://vega.github.io/vega/)\n\nFundamentally, all this module does is convert a `Booster` into a format that can be\ningested by Vega, and apply some default configuations that only account for a subset of the configurations\nthat can be set by a Vega spec directly. The functions provided in this module are designed to have opinionated\ndefaults that can be used to quickly visualize a model, but the full power of Vega is available by using the\n`to_tabular/1` function to convert the model into a tabular format, and then using the `plot/2` function\nto convert the tabular format into a Vega specification.","ref":"EXGBoost.Plotting.html"},{"type":"module","title":"Default Vega Specification - EXGBoost.Plotting","doc":"The default Vega specification is designed to be a good starting point for visualizing a model, but it is\npossible to customize the specification by passing in a map of Vega properties to the `plot/2` function.\nRefer to `Custom Vega Specifications` for more details on how to do this.\n\nBy default, the Vega specification includes the following entities to use for rendering the model:\n* `:width` - The width of the plot in pixels\n* `:height` - The height of the plot in pixels\n* `:padding` - The padding in pixels to add around the visualization. If a number, specifies padding for all sides. If an object, the value should have the format `[left: value, right: value, top: value, bottom: value]`\n* `:leafs` - Specifies characteristics of leaf nodes\n* `:inner_nodes` - Specifies characteristics of inner nodes\n* `:links` - Specifies characteristics of links between nodes","ref":"EXGBoost.Plotting.html#module-default-vega-specification"},{"type":"module","title":"Custom Vega Specifications - EXGBoost.Plotting","doc":"The default Vega specification is designed to be a good starting point for visualizing a model, but it is\npossible to customize the specification by passing in a map of Vega properties to the `plot/2` function.\nYou can find the full list of Vega properties [here](https://vega.github.io/vega/docs/specification/).\n\nIt is suggested that you use the data attributes provided by the default specification as a starting point, since they\nprovide the necessary data transformation to convert the model into a tree structure that can be visualized by Vega.\nIf you would like to customize the default specification, you can use `EXGBoost.Plotting.plot/1` to get the default\nspecification, and then modify it as needed.\n\nOnce you have a custom specification, you can pass it to `VegaLite.from_json/1` to create a new `VegaLite` struct, after which\nyou can use the functions provided by the `VegaLite` module to render the model.","ref":"EXGBoost.Plotting.html#module-custom-vega-specifications"},{"type":"module","title":"Specification Validation - EXGBoost.Plotting","doc":"You can optionally validate your specification against the Vega schema by passing the `validate: true` option to `plot/2`.\nThis will raise an error if the specification is invalid. This is useful if you are creating a custom specification and want\nto ensure that it is valid. Note that this will only validate the specification against the Vega schema, and not against the\nVegaLite schema. This requires the [`ex_json_schema`] package to be installed.","ref":"EXGBoost.Plotting.html#module-specification-validation"},{"type":"module","title":"Livebook Integration - EXGBoost.Plotting","doc":"This module also provides a `Kino.Render` implementation for `EXGBoost.Booster` which allows\nmodels to be rendered directly in Livebook. This is done by converting the model into a Vega specification\nand then using the `Kino.Render` implementation for Elixir's [`VegaLite`](https://hexdocs.pm/vega_lite/VegaLite.html) API\nto render the model.\n\n. The Vega specification is then passed to [VegaLite](https://hexdocs.pm/vega_lite/readme.html)","ref":"EXGBoost.Plotting.html#module-livebook-integration"},{"type":"module","title":"Plotting Parameters - EXGBoost.Plotting","doc":"This module exposes a high-level API for customizing the EXGBoost model visualization, but it is also possible to\ncustomize the Vega specification directly. You can also choose to pass in Vega Mark specifications to customize the\nappearance of the nodes and links in the visualization outside of the parameteres specified below. Refer to the\n[Vega documentation](https://vega.github.io/vega/docs/marks/) for more details on how to do this.\n\n* `:style` - The style to use for the visualization. Refer to `EXGBoost.Plotting.Styles` for a list of available styles. The default value is `:dracula`.\n\n* `:rankdir` - Determines the direction of the graph. The default value is `:tb`.\n\n* `:autosize` - Determines if the visualization should automatically resize when the window size changes The default value is `\"fit\"`.\n\n* `:background` (`t:String.t/0`) - The background color of the visualization. Accepts a valid CSS color string. For example: `#f304d3`, `#ccc`, `rgb(253, 12, 134)`, `steelblue.` The default value is `\"#f5f5f5\"`.\n\n* `:height` (`t:pos_integer/0`) - Height of the plot in pixels The default value is `400`.\n\n* `:width` (`t:pos_integer/0`) - Width of the plot in pixels The default value is `600`.\n\n* `:padding` - The padding in pixels to add around the visualization. If a number, specifies padding for all sides. If an object, the value should have the format `[left: value, right: value, top: value, bottom: value]` The default value is `30`.\n\n* `:leaves` (`t:keyword/0`) - Specifies characteristics of leaf nodes The default value is `[text: [align: :center, baseline: :middle, font_size: 13, font: \"Calibri\"], rect: [corner_radius: 2, opacity: 1]]`.\n\n  * `:text` (`t:keyword/0`) - Accepts a keyword list of Vega `text` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/text/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[align: :center, baseline: :middle, font_size: 13, font: \"Calibri\"]`.\n\n  * `:rect` (`t:keyword/0`) - Accepts a keyword list of Vega `rect` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/rect/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[corner_radius: 2, opacity: 1]`.\n\n* `:splits` (`t:keyword/0`) - Specifies characteristics of split nodes The default value is `[text: [align: :center, baseline: :middle, font_size: 13, font: \"Calibri\"], rect: [corner_radius: 2, opacity: 1], children: [align: :right, baseline: :middle, font: \"Calibri\", font_size: 13]]`.\n\n  * `:text` (`t:keyword/0`) - Accepts a keyword list of Vega `text` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/text/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[align: :center, baseline: :middle, font_size: 13, font: \"Calibri\"]`.\n\n  * `:rect` (`t:keyword/0`) - Accepts a keyword list of Vega `rect` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/rect/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[corner_radius: 2, opacity: 1]`.\n\n  * `:children` (`t:keyword/0`) - Accepts a keyword list of Vega `text` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/text/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[align: :right, baseline: :middle, font: \"Calibri\", font_size: 13]`.\n\n* `:node_width` (`t:pos_integer/0`) - The width of each node in pixels The default value is `100`.\n\n* `:node_height` (`t:pos_integer/0`) - The height of each node in pixels The default value is `45`.\n\n* `:space_between` (`t:keyword/0`) - The space between the rectangular marks in pixels. The default value is `[nodes: 10, levels: 100]`.\n\n  * `:nodes` (`t:pos_integer/0`) - Space between marks within the same depth of the tree. The default value is `10`.\n\n  * `:levels` (`t:pos_integer/0`) - Space between each rank / depth of the tree. The default value is `100`.\n\n* `:yes` (`t:keyword/0`) - Specifies characteristics of links between nodes where the split condition is true The default value is `[path: [], text: [align: :center, baseline: :middle, font_size: 13, font: \"Calibri\", text: \"yes\"]]`.\n\n  * `:path` (`t:keyword/0`) - Accepts a keyword list of Vega `path` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/path/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[]`.\n\n  * `:text` (`t:keyword/0`) - Accepts a keyword list of Vega `text` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/text/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[align: :center, baseline: :middle, font_size: 13, font: \"Calibri\", text: \"yes\"]`.\n\n* `:no` (`t:keyword/0`) - Specifies characteristics of links between nodes where the split condition is false The default value is `[path: [], text: [align: :center, baseline: :middle, font_size: 13, font: \"Calibri\", text: \"no\"]]`.\n\n  * `:path` (`t:keyword/0`) - Accepts a keyword list of Vega `path` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/path/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[]`.\n\n  * `:text` (`t:keyword/0`) - Accepts a keyword list of Vega `text` Mark properties. Reference [here](https://vega.github.io/vega/docs/marks/text/) for more details. Accepts either a string (expected to be valid Vega property names) or Elixir-styled atom. Note that keys are snake-cased instead of camel-case (e.g. Vega `fontSize` becomes `font_size`) The default value is `[align: :center, baseline: :middle, font_size: 13, font: \"Calibri\", text: \"no\"]`.\n\n* `:validate` (`t:boolean/0`) - Whether to validate the Vega specification against the Vega schema The default value is `true`.\n\n* `:index` - The zero-indexed index of the tree to plot. If `nil`, plots all trees using a dropdown selector to switch between trees The default value is `0`.\n\n* `:depth` - The depth of the tree to plot. If `nil`, plots all levels (cick on a node to expand/collapse) The default value is `nil`.","ref":"EXGBoost.Plotting.html#module-plotting-parameters"},{"type":"module","title":"Styles - EXGBoost.Plotting","doc":"Styles are a keyword-map that adhere to the plotting schema as defined in `EXGBoost.Plotting`.\n`EXGBoost.Plotting.Styles` provides a set of predefined styles that can be used to quickly customize the appearance of the visualization.\n\n\nRefer to the `EXGBoost.Plotting.Styles` module for a list of available styles. You can pass a style to the `:style`\noption as an atom or string, and it will be applied to the visualization. Styles will override any other options that are passed\nfor each option where the style defined a value. For example, if you pass `:solarized_light` as the style, and also pass\n`:background` as an option, the `:background` option will be ignored since the `:solarized_light` style defines its own value for `:background`.","ref":"EXGBoost.Plotting.html#module-styles"},{"type":"function","title":"EXGBoost.Plotting.dark/0","doc":"A dark theme","ref":"EXGBoost.Plotting.html#dark/0"},{"type":"function","title":"EXGBoost.Plotting.dracula/0","doc":"A theme based on the [Dracula](https://draculatheme.com/) color palette","ref":"EXGBoost.Plotting.html#dracula/0"},{"type":"function","title":"EXGBoost.Plotting.get_data_spec/2","doc":"Generates the necessary data transformation to convert the model into a tree structure that can be visualized by Vega.\n\nThis function is useful if you want to create a custom Vega specification, but still want to use the data transformation\nprovided by the default specification.","ref":"EXGBoost.Plotting.html#get_data_spec/2"},{"type":"function","title":"Options - EXGBoost.Plotting.get_data_spec/2","doc":"* `:rankdir` - Determines the direction of the graph. Accepts one of `:tb`, `:lr`, `:bt`, or `:rl`. Defaults to `:tb`","ref":"EXGBoost.Plotting.html#get_data_spec/2-options"},{"type":"function","title":"EXGBoost.Plotting.get_defaults/0","doc":"","ref":"EXGBoost.Plotting.html#get_defaults/0"},{"type":"function","title":"EXGBoost.Plotting.get_schema/0","doc":"","ref":"EXGBoost.Plotting.html#get_schema/0"},{"type":"function","title":"EXGBoost.Plotting.get_styles/0","doc":"","ref":"EXGBoost.Plotting.html#get_styles/0"},{"type":"function","title":"EXGBoost.Plotting.gruvbox/0","doc":"A theme based on the [Gruvbox](https://github.com/morhetz/gruvbox) color palette","ref":"EXGBoost.Plotting.html#gruvbox/0"},{"type":"function","title":"EXGBoost.Plotting.high_contrast/0","doc":"A high contrast theme","ref":"EXGBoost.Plotting.html#high_contrast/0"},{"type":"function","title":"EXGBoost.Plotting.horizon_dark/0","doc":"A dark theme based on the [Horizon](https://www.horizon.io/) color palette","ref":"EXGBoost.Plotting.html#horizon_dark/0"},{"type":"function","title":"EXGBoost.Plotting.horizon_light/0","doc":"A light theme based on the [Horizon](https://www.horizon.io/) color palette","ref":"EXGBoost.Plotting.html#horizon_light/0"},{"type":"function","title":"EXGBoost.Plotting.light/0","doc":"A light theme","ref":"EXGBoost.Plotting.html#light/0"},{"type":"function","title":"EXGBoost.Plotting.material/0","doc":"A theme based on the [Material](https://material.io/design/color/the-color-system.html#tools-for-picking-colors) color palette","ref":"EXGBoost.Plotting.html#material/0"},{"type":"function","title":"EXGBoost.Plotting.monokai/0","doc":"A theme based on the [Monokai](https://monokai.pro/) color palette","ref":"EXGBoost.Plotting.html#monokai/0"},{"type":"function","title":"EXGBoost.Plotting.nord/0","doc":"A theme based on the [Nord](https://www.nordtheme.com/) color palette","ref":"EXGBoost.Plotting.html#nord/0"},{"type":"function","title":"EXGBoost.Plotting.one_dark/0","doc":"A theme based on the One Dark color palette","ref":"EXGBoost.Plotting.html#one_dark/0"},{"type":"function","title":"EXGBoost.Plotting.playful_dark/0","doc":"A dark and playful theme","ref":"EXGBoost.Plotting.html#playful_dark/0"},{"type":"function","title":"EXGBoost.Plotting.playful_light/0","doc":"A light and playful theme","ref":"EXGBoost.Plotting.html#playful_light/0"},{"type":"function","title":"EXGBoost.Plotting.plot/2","doc":"","ref":"EXGBoost.Plotting.html#plot/2"},{"type":"function","title":"EXGBoost.Plotting.solarized_dark/0","doc":"A dark theme based on the [Solarized](https://ethanschoonover.com/solarized/) color palette","ref":"EXGBoost.Plotting.html#solarized_dark/0"},{"type":"function","title":"EXGBoost.Plotting.solarized_light/0","doc":"A light theme based on the [Solarized](https://ethanschoonover.com/solarized/) color palette","ref":"EXGBoost.Plotting.html#solarized_light/0"},{"type":"function","title":"EXGBoost.Plotting.to_tabular/1","doc":"Outputs details of the tree in a tabular format which can be consumed\nby plotting libraries such as Vega. Outputs as a list of maps, where\neach map represents a node in the tree.\n\nTable columns:\n- tree_id: The tree id\n- nodeid: The node id\n- parentid: The parent node id\n- split: The split feature\n- split_condition: The split condition\n- yes: The node id of the left child\n- no: The node id of the right child\n- missing: The node id of the missing child\n- depth: The depth of the node (root node is depth 1)\n- leaf: The leaf value if it is a leaf node","ref":"EXGBoost.Plotting.html#to_tabular/1"},{"type":"type","title":"EXGBoost.Plotting.style/0","doc":"","ref":"EXGBoost.Plotting.html#t:style/0"},{"type":"module","title":"EXGBoost.Plotting.Styles","doc":"horizon_light \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#FDF0ED\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#1A2026\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#1A2026\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#48B685\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#F43E5C\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#F43E5C\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#1A2026\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#1A2026\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#1A2026\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#1A2026\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#F7E3D3\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#F43E5C\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#1A2026\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   horizon_dark \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#1C1E26\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#E3E6EE\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#E3E6EE\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#48B685\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#F43E5C\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#F43E5C\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#E3E6EE\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#E3E6EE\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#E3E6EE\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#E3E6EE\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#232530\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#F43E5C\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#E3E6EE\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   gruvbox \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#282828\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#ebdbb2\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#ebdbb2\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#b8bb26\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fb4934\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#b8bb26\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#ebdbb2\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#ebdbb2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#ebdbb2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#ebdbb2\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#3c3836\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#b8bb26\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#ebdbb2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   one_dark \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#282c34\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#abb2bf\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#abb2bf\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#98c379\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#e06c75\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#98c379\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#abb2bf\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#abb2bf\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#abb2bf\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#abb2bf\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#3b4048\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#98c379\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#abb2bf\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   material \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#263238\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#eceff1\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#eceff1\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#c5e1a5\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#ef9a9a\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#80cbc4\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#eceff1\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#eceff1\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#eceff1\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#eceff1\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#37474f\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#80cbc4\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#eceff1\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   nord \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#2e3440\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#d8dee9\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#d8dee9\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#a3be8c\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#bf616a\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#88c0d0\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#d8dee9\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#d8dee9\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#d8dee9\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#d8dee9\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#3b4252\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#88c0d0\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#d8dee9\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   dracula \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#282a36\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#50fa7b\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#ff5555\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#ff79c6\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#44475a\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#ff79c6\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   monokai \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#272822\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#a6e22e\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f92672\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#66d9ef\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#f8f8f2\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#3e3d32\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#66d9ef\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f8f8f2\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   light \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#f0f0f0\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#bbb\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#000\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#000\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#ddd\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#000\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#000\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":10,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   high_contrast \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#000\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#666\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#fff\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#333\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#fff\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":10,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   dark \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#333\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#444\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#fff\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#fff\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#666\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#fff\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":10,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   playful_dark \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#333\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#4caf50\"},\"strokeWidth\":{\"value\":2},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#f44336\"},\"strokeWidth\":{\"value\":2}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#4caf50\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#f44336\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#8bc34a\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"radius\":{\"value\":10},\"stroke\":{\"value\":\"#fff\"},\"strokeWidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontStyle\":{\"value\":\"normal\"},\"fontWeight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#e91e63\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"radius\":{\"value\":5},\"stroke\":{\"value\":\"#fff\"},\"strokeWidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#fff\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontStyle\":{\"value\":\"italic\"},\"fontWeight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":10,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   playful_light \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#f0f0f0\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#4caf50\"},\"strokeWidth\":{\"value\":2},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#f44336\"},\"strokeWidth\":{\"value\":2}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#8bc34a\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"radius\":{\"value\":10},\"stroke\":{\"value\":\"#000\"},\"strokeWidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#000\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontStyle\":{\"value\":\"normal\"},\"fontWeight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#000\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontStyle\":{\"value\":\"normal\"},\"fontWeight\":{\"value\":\"bold\"},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#e91e63\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"radius\":{\"value\":5},\"stroke\":{\"value\":\"#000\"},\"strokeWidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#000\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontStyle\":{\"value\":\"italic\"},\"fontWeight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":10,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   solarized_dark \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#002b36\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#657b83\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#859900\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#dc322f\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#586e75\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#839496\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#657b83\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#073642\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#586e75\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#839496\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}\n     \n   \n \n\n\n \n   solarized_light \n   \n     \n    {\"$schema\":\"https://vega.github.io/schema/vega/v5.json\",\"autosize\":\"fit\",\"background\":\"#fdf6e3\",\"data\":[{\"name\":\"tree\",\"values\":[{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":0,\"yes\":2},{\"depth\":null,\"leaf\":0.427624315,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":null,\"leaf\":-0.21861203,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":0,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":1,\"yes\":2},{\"depth\":null,\"leaf\":-0.213812172,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":1,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":1,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":1,\"yes\":10},{\"depth\":null,\"leaf\":0.421276599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.128571421,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":0.0310344752,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":1,\"yes\":8},{\"depth\":null,\"leaf\":-7.66345476e-9,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":null,\"leaf\":-0.210638314,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":1,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":2,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":2,\"yes\":4},{\"depth\":null,\"leaf\":-0.218691617,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.179999992,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":null,\"leaf\":0.391304374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":2,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":3,\"yes\":2},{\"depth\":null,\"leaf\":0.293898225,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":null,\"leaf\":-0.195709914,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":3,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":4,\"yes\":2},{\"depth\":null,\"leaf\":-0.190234631,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":4,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":4,\"yes\":6},{\"depth\":null,\"leaf\":0.282141834,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":0.0305235293,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":4,\"yes\":8},{\"depth\":null,\"leaf\":0.0113703683,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":null,\"leaf\":-0.188464046,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":4,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":5,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":5,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":5,\"yes\":8},{\"depth\":null,\"leaf\":-0.194885567,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":-0.00233711768,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.0858411044,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":5,\"yes\":6},{\"depth\":null,\"leaf\":0.078266032,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":null,\"leaf\":0.295715213,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":5,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":6,\"yes\":2},{\"depth\":null,\"leaf\":0.235398397,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":null,\"leaf\":-0.180213198,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":6,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":7,\"yes\":2},{\"depth\":null,\"leaf\":-0.174046159,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":7,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":7,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":7,\"yes\":10},{\"depth\":null,\"leaf\":0.0794009417,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.235855803,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":0.0254845936,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":7,\"yes\":8},{\"depth\":null,\"leaf\":0.00953481626,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":null,\"leaf\":-0.171851099,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":7,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":8,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":8,\"yes\":4},{\"depth\":null,\"leaf\":-0.178984255,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.00731091993,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":8,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":8,\"yes\":8},{\"depth\":null,\"leaf\":0.122805104,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":-0.0581566244,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":8,\"yes\":10},{\"depth\":null,\"leaf\":0.0640309602,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":null,\"leaf\":0.235631004,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":8,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":9,\"yes\":2},{\"depth\":null,\"leaf\":0.202927306,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":null,\"leaf\":-0.169219166,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":9,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":10,\"yes\":2},{\"depth\":null,\"leaf\":-0.161958873,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":10,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":10,\"yes\":10},{\"depth\":null,\"leaf\":0.0595290773,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":10,\"yes\":12},{\"depth\":null,\"leaf\":0.0330740288,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":0.210039064,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.0136675909,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":10,\"yes\":8},{\"depth\":null,\"leaf\":0.00858953688,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":null,\"leaf\":-0.159253284,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":10,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":11,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":11,\"yes\":4},{\"depth\":null,\"leaf\":-0.167691931,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.013599243,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":11,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":11,\"yes\":8},{\"depth\":null,\"leaf\":0.111706354,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":-0.0548854023,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":11,\"yes\":10},{\"depth\":null,\"leaf\":0.0527966879,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":null,\"leaf\":0.202194899,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":11,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":12,\"yes\":2},{\"depth\":null,\"leaf\":0.182395548,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":null,\"leaf\":-0.160902798,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":12,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":13,\"yes\":2},{\"depth\":null,\"leaf\":-0.152229458,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":13,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":13,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":13,\"yes\":10},{\"depth\":null,\"leaf\":0.182105944,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.0296379086,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":0.00951357931,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":13,\"yes\":8},{\"depth\":null,\"leaf\":-0.00339872413,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":null,\"leaf\":-0.153260142,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":13,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":14,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":14,\"yes\":4},{\"depth\":null,\"leaf\":-0.159062892,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.0197537746,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":14,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":14,\"yes\":8},{\"depth\":null,\"leaf\":0.102480493,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":-0.0490195006,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":14,\"yes\":10},{\"depth\":null,\"leaf\":0.0437330343,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":null,\"leaf\":0.180924967,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":14,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":15,\"yes\":2},{\"depth\":null,\"leaf\":0.16810815,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":null,\"leaf\":-0.154098362,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":15,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":16,\"yes\":2},{\"depth\":null,\"leaf\":-0.143788517,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":16,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":6,\"parentid\":4,\"split\":\"f0\",\"split_condition\":5.0999999,\"tree_id\":16,\"yes\":10},{\"depth\":null,\"leaf\":0.0220483318,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":4,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":11,\"parentid\":6,\"split\":\"f1\",\"split_condition\":2.29999995,\"tree_id\":16,\"yes\":12},{\"depth\":null,\"leaf\":0.00895943958,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":0.176665574,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":11,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.0206642058,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":4.9000001,\"tree_id\":16,\"yes\":8},{\"depth\":null,\"leaf\":0.017383676,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":null,\"leaf\":-0.140686065,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":16,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":17,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":17,\"yes\":4},{\"depth\":null,\"leaf\":-0.151693538,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.0178305581,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":17,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":17,\"yes\":8},{\"depth\":null,\"leaf\":0.110296227,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":-0.0546041094,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.0999999,\"tree_id\":17,\"yes\":10},{\"depth\":null,\"leaf\":0.0373543724,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":null,\"leaf\":0.17702879,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":17,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":18,\"yes\":2},{\"depth\":null,\"leaf\":0.157291308,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":null,\"leaf\":-0.148284495,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":18,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":19,\"yes\":2},{\"depth\":null,\"leaf\":-0.13595058,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":19,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":19,\"yes\":6},{\"depth\":null,\"leaf\":0.161282361,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.0456363559,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":19,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":19,\"yes\":10},{\"depth\":null,\"leaf\":-0.12643297,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":0.0939816386,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":null,\"leaf\":-0.129954055,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":19,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":4.80000019,\"tree_id\":20,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.60000002,\"tree_id\":20,\"yes\":4},{\"depth\":null,\"leaf\":-0.14539367,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.0229678843,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":20,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":20,\"yes\":8},{\"depth\":null,\"leaf\":0.0849196538,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":-0.0489643775,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":20,\"yes\":10},{\"depth\":3,\"leaf\":null,\"missing\":12,\"no\":13,\"nodeid\":10,\"parentid\":7,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":20,\"yes\":12},{\"depth\":null,\"leaf\":-0.0374543481,\"missing\":null,\"no\":null,\"nodeid\":12,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.09419626,\"missing\":null,\"no\":null,\"nodeid\":13,\"parentid\":10,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":null,\"leaf\":0.161539495,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":20,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":21,\"yes\":2},{\"depth\":null,\"leaf\":0.148412958,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":null,\"leaf\":-0.142748639,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":21,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":22,\"yes\":2},{\"depth\":null,\"leaf\":-0.128286615,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":22,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":22,\"yes\":6},{\"depth\":null,\"leaf\":0.152010709,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.0427916795,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":22,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":22,\"yes\":10},{\"depth\":null,\"leaf\":-0.118150115,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":0.0858531445,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":null,\"leaf\":-0.121662959,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":22,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":23,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":23,\"yes\":4},{\"depth\":null,\"leaf\":-0.143794015,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.0814001635,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.0999999,\"tree_id\":23,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":23,\"yes\":8},{\"depth\":null,\"leaf\":0.141156599,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":-0.0439796187,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":null,\"leaf\":0.143892258,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":23,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":24,\"yes\":2},{\"depth\":null,\"leaf\":0.140514985,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":null,\"leaf\":-0.137244374,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":24,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":25,\"yes\":2},{\"depth\":null,\"leaf\":-0.120564461,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":25,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":25,\"yes\":6},{\"depth\":null,\"leaf\":0.142616123,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":-0.0347704254,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":5,\"parentid\":3,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":25,\"yes\":8},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":8,\"parentid\":5,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":25,\"yes\":10},{\"depth\":null,\"leaf\":-0.136967599,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.00531567633,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":8,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":null,\"leaf\":0.0164541826,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":25,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":26,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":26,\"yes\":4},{\"depth\":null,\"leaf\":-0.137371227,\"missing\":null,\"no\":null,\"nodeid\":4,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0680029839,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":2,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f1\",\"split_condition\":3.20000005,\"tree_id\":26,\"yes\":6},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5999999,\"tree_id\":26,\"yes\":8},{\"depth\":null,\"leaf\":0.155390441,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0413417891,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":3,\"split\":\"f0\",\"split_condition\":6.5,\"tree_id\":26,\"yes\":10},{\"depth\":null,\"leaf\":-0.0276773833,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":null,\"leaf\":0.0837894604,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":26,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":27,\"yes\":2},{\"depth\":null,\"leaf\":0.133121789,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":null,\"leaf\":-0.131964371,\"missing\":null,\"no\":null,\"nodeid\":3,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":27,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f2\",\"split_condition\":3,\"tree_id\":28,\"yes\":2},{\"depth\":null,\"leaf\":-0.112695776,\"missing\":null,\"no\":null,\"nodeid\":2,\"parentid\":1,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":3,\"parentid\":1,\"split\":\"f2\",\"split_condition\":5.30000019,\"tree_id\":28,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":4,\"parentid\":3,\"split\":\"f3\",\"split_condition\":1.70000005,\"tree_id\":28,\"yes\":6},{\"depth\":3,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":6,\"parentid\":4,\"split\":\"f2\",\"split_condition\":5,\"tree_id\":28,\"yes\":8},{\"depth\":null,\"leaf\":0.134010807,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.00136732496,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":6,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":3,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":7,\"parentid\":4,\"split\":\"f1\",\"split_condition\":2.9000001,\"tree_id\":28,\"yes\":10},{\"depth\":null,\"leaf\":-0.101361156,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":0.0597268902,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":7,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":null,\"leaf\":-0.112027228,\"missing\":null,\"no\":null,\"nodeid\":5,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":28,\"yes\":null},{\"depth\":0,\"leaf\":null,\"missing\":2,\"no\":3,\"nodeid\":1,\"parentid\":null,\"split\":\"f3\",\"split_condition\":1.79999995,\"tree_id\":29,\"yes\":2},{\"depth\":1,\"leaf\":null,\"missing\":4,\"no\":5,\"nodeid\":2,\"parentid\":1,\"split\":\"f1\",\"split_condition\":2.70000005,\"tree_id\":29,\"yes\":4},{\"depth\":2,\"leaf\":null,\"missing\":8,\"no\":9,\"nodeid\":4,\"parentid\":2,\"split\":\"f3\",\"split_condition\":1.5,\"tree_id\":29,\"yes\":8},{\"depth\":null,\"leaf\":-0.0157809388,\"missing\":null,\"no\":null,\"nodeid\":8,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.0803615674,\"missing\":null,\"no\":null,\"nodeid\":9,\"parentid\":4,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":2,\"leaf\":null,\"missing\":10,\"no\":11,\"nodeid\":5,\"parentid\":2,\"split\":\"f0\",\"split_condition\":6.30000019,\"tree_id\":29,\"yes\":10},{\"depth\":null,\"leaf\":-0.139912695,\"missing\":null,\"no\":null,\"nodeid\":10,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":-0.0307020787,\"missing\":null,\"no\":null,\"nodeid\":11,\"parentid\":5,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":1,\"leaf\":null,\"missing\":6,\"no\":7,\"nodeid\":3,\"parentid\":1,\"split\":\"f0\",\"split_condition\":6,\"tree_id\":29,\"yes\":6},{\"depth\":null,\"leaf\":-0.00209752563,\"missing\":null,\"no\":null,\"nodeid\":6,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null},{\"depth\":null,\"leaf\":0.138928756,\"missing\":null,\"no\":null,\"nodeid\":7,\"parentid\":3,\"split\":null,\"split_condition\":null,\"tree_id\":29,\"yes\":null}]},{\"name\":\"treeCalcs\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"}]},{\"name\":\"treeChildren\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":[\"childrenObjects\"],\"fields\":[\"parentid\"],\"groupby\":[\"parentid\"],\"ops\":[\"values\"],\"type\":\"aggregate\"},{\"as\":\"childrenIds\",\"expr\":\"pluck(datum.childrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeAncestors\",\"source\":\"treeCalcs\",\"transform\":[{\"as\":\"treeAncestors\",\"expr\":\"treeAncestors('treeCalcs', datum.nodeid, 'root')\",\"type\":\"formula\"},{\"fields\":[\"treeAncestors\"],\"type\":\"flatten\"},{\"as\":\"allParents\",\"expr\":\"datum.treeAncestors.parentid\",\"type\":\"formula\"}]},{\"name\":\"treeChildrenAll\",\"source\":\"treeAncestors\",\"transform\":[{\"fields\":[\"allParents\",\"nodeid\",\"name\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"as\":[\"allChildrenObjects\",\"allChildrenCount\",\"id\"],\"fields\":[\"parentid\",\"parentid\",\"nodeid\"],\"groupby\":[\"allParents\"],\"ops\":[\"values\",\"count\",\"min\"],\"type\":\"aggregate\"},{\"as\":\"allChildrenIds\",\"expr\":\"pluck(datum.allChildrenObjects,'nodeid')\",\"type\":\"formula\"}]},{\"name\":\"treeClickStoreTemp\",\"source\":\"treeAncestors\",\"transform\":[{\"expr\":\"startingDepth != -1 ? datum.depth <= startingDepth : node != 0 && !isExpanded ? datum.parentid == node: node != 0 && isExpanded ? datum.allParents == node : false\",\"type\":\"filter\"},{\"fields\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"type\":\"project\"},{\"fields\":[\"nodeid\"],\"groupby\":[\"nodeid\",\"parentid\",\"x\",\"y\",\"depth\",\"children\"],\"ops\":[\"min\"],\"type\":\"aggregate\"}]},{\"name\":\"treeClickStorePerm\",\"on\":[{\"insert\":\"data('treeClickStoreTemp')\",\"trigger\":\"startingDepth >= 0\"},{\"insert\":\"!isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"},{\"remove\":\"isExpanded ? data('treeClickStoreTemp'): false\",\"trigger\":\"node\"}],\"values\":[]},{\"name\":\"treeLayout\",\"source\":\"tree\",\"transform\":[{\"expr\":\"datum.tree_id === selectedTree\",\"type\":\"filter\"},{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid)\",\"type\":\"filter\"},{\"key\":\"nodeid\",\"parentKey\":\"parentid\",\"type\":\"stratify\"},{\"as\":[\"x\",\"y\",\"depth\",\"children\"],\"method\":\"tidy\",\"nodeSize\":[{\"signal\":\"nodeWidth + spaceBetweenNodes\"},{\"signal\":\"nodeHeight+ spaceBetweenLevels\"}],\"separation\":{\"signal\":\"false\"},\"type\":\"tree\"},{\"as\":\"y\",\"expr\":\"1*(datum.y+(height/10))\",\"type\":\"formula\"},{\"as\":\"x\",\"expr\":\"1*(datum.x+(width/2))\",\"type\":\"formula\"},{\"field\":\"x\",\"signal\":\"x_extent\",\"type\":\"extent\"},{\"field\":\"y\",\"signal\":\"y_extent\",\"type\":\"extent\"},{\"as\":\"xscaled\",\"expr\":\"scale('xscale',datum.x)\",\"type\":\"formula\"},{\"as\":\"parent\",\"expr\":\"datum.parentid\",\"type\":\"formula\"}]},{\"name\":\"fullTreeLayout\",\"source\":\"treeLayout\",\"transform\":[{\"fields\":[\"nodeid\"],\"from\":\"treeChildren\",\"key\":\"parentid\",\"type\":\"lookup\",\"values\":[\"childrenObjects\",\"childrenIds\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeChildrenAll\",\"key\":\"allParents\",\"type\":\"lookup\",\"values\":[\"allChildrenIds\",\"allChildrenObjects\"]},{\"fields\":[\"nodeid\"],\"from\":\"treeCalcs\",\"key\":\"nodeid\",\"type\":\"lookup\",\"values\":[\"children\"]},{\"as\":\"treeParent\",\"expr\":\"reverse(pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid'))[1]\",\"type\":\"formula\"},{\"as\":\"isLeaf\",\"expr\":\"datum.leaf == null\",\"type\":\"formula\"}]},{\"name\":\"splitNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"leafNodes\",\"source\":\"fullTreeLayout\",\"transform\":[{\"expr\":\"indata('treeClickStorePerm', 'nodeid', datum.nodeid) && !datum.isLeaf\",\"type\":\"filter\"}]},{\"name\":\"links\",\"source\":\"treeLayout\",\"transform\":[{\"type\":\"treelinks\"},{\"orient\":\"vertical\",\"shape\":\"line\",\"sourceX\":{\"expr\":\"scale('xscale', datum.source.x)\"},\"sourceY\":{\"expr\":\"scale('yscale', datum.source.y)\"},\"targetX\":{\"expr\":\"scale('xscale', datum.target.x)\"},\"targetY\":{\"expr\":\"scale('yscale', datum.target.y) - scaledNodeHeight\"},\"type\":\"linkpath\"},{\"expr\":\" indata('treeClickStorePerm', 'nodeid', datum.target.nodeid)\",\"type\":\"filter\"}]},{\"name\":\"yesPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes === datum.target.nodeid \",\"type\":\"filter\"}]},{\"name\":\"noPaths\",\"source\":\"links\",\"transform\":[{\"expr\":\"datum.source.yes !== datum.target.nodeid \",\"type\":\"filter\"}]}],\"height\":200,\"marks\":[{\"encode\":{\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"update\":{\"path\":{\"field\":\"path\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"}}},\"from\":{\"data\":\"yesPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"path\":{\"field\":\"path\"},\"stroke\":{\"value\":\"#657b83\"},\"strokeWidth\":{\"signal\":\"indexof(nodeHighlight, datum.target.nodeid)> -1? 2:1\"},\"strokewidth\":{\"value\":1}}},\"from\":{\"data\":\"noPaths\"},\"interactive\":false,\"type\":\"path\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#859900\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"yes\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"yesPaths\"},\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#dc322f\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"text\":{\"value\":\"no\"},\"x\":{\"signal\":\"(scale('xscale', datum.source.x-nodeWidth/4) + scale('xscale', datum.target.x)) / 2\"},\"y\":{\"signal\":\"(scale('yscale', datum.source.y) + scale('yscale', datum.target.y)) / 2 - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"noPaths\"},\"type\":\"text\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#93a1a1\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"splitNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#586e75\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"bold\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"parent.split + ' <= ' + format(parent.split_condition, '.2f')\"},\"x\":{\"signal\":\"(scaledNodeWidth / 2)\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"},{\"encode\":{\"update\":{\"align\":{\"value\":\"right\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#657b83\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"stroke\":{\"value\":\"#657b83\"},\"strokewidth\":{\"value\":1},\"text\":{\"signal\":\"parent.children\"},\"x\":{\"signal\":\"item.mark.group.width - (9/ span(xdom))*width\"},\"y\":{\"signal\":\"item.mark.group.height/2\"}}},\"interactive\":false,\"type\":\"text\"}],\"name\":\"splitNode\",\"type\":\"group\"},{\"clip\":false,\"encode\":{\"update\":{\"cornerRadius\":{\"value\":2},\"cursor\":{\"signal\":\"datum.children > 0 ? 'pointer' : '' \"},\"fill\":{\"value\":\"#eee8d5\"},\"height\":{\"signal\":\"scaledNodeHeight\"},\"opacity\":{\"value\":1},\"stroke\":{\"value\":\"#93a1a1\"},\"strokewidth\":{\"value\":1},\"tooltip\":{\"signal\":\"\"},\"width\":{\"signal\":\"scaledNodeWidth\"},\"x\":{\"signal\":\"datum.xscaled - (scaledNodeWidth / 2)\"},\"yc\":{\"signal\":\"scale('yscale',datum.y) - (scaledNodeHeight/2)\"}}},\"from\":{\"data\":\"leafNodes\"},\"marks\":[{\"encode\":{\"update\":{\"align\":{\"value\":\"center\"},\"baseline\":{\"value\":\"middle\"},\"fill\":{\"value\":\"#586e75\"},\"font\":{\"value\":\"Calibri\"},\"fontSize\":{\"signal\":\"(13/ span(xdom))*width\"},\"fontsize\":{\"value\":12},\"fontstyle\":{\"value\":\"normal\"},\"fontweight\":{\"value\":\"normal\"},\"limit\":{\"signal\":\"scaledNodeWidth-scaledLimit\"},\"text\":{\"signal\":\"'leaf = ' + format(parent.leaf, '.2f')\"},\"x\":{\"signal\":\"scaledNodeWidth / 2\"},\"y\":{\"signal\":\"scaledNodeHeight / 2\"}}},\"interactive\":false,\"name\":\"title\",\"type\":\"text\"}],\"name\":\"leafNode\",\"type\":\"group\"}],\"padding\":30,\"scales\":[{\"domain\":{\"signal\":\"xdom\"},\"name\":\"xscale\",\"range\":{\"signal\":\"xrange\"},\"zero\":false},{\"domain\":{\"signal\":\"ydom\"},\"name\":\"yscale\",\"range\":{\"signal\":\"yrange\"},\"zero\":false}],\"signals\":[{\"name\":\"selectedTree\",\"value\":0},{\"name\":\"node\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.nodeid\"}],\"value\":0},{\"name\":\"nodeHighlight\",\"on\":[{\"events\":[{\"markname\":\"splitNode\",\"type\":\"mouseover\"},{\"markname\":\"leafNode\",\"type\":\"mouseover\"}],\"update\":\"pluck(treeAncestors('treeCalcs', datum.nodeid), 'nodeid')\"},{\"events\":{\"type\":\"mouseout\"},\"update\":\"[0]\"}],\"value\":\"[0]\"},{\"name\":\"isExpanded\",\"on\":[{\"events\":{\"markname\":\"splitNode\",\"type\":\"click\"},\"update\":\"datum.children > 0 && indata('treeClickStorePerm', 'nodeid', datum.childrenIds[0]) ? true : false\"}],\"value\":0},{\"name\":\"xrange\",\"update\":\"[0, width]\"},{\"name\":\"yrange\",\"update\":\"[0, height]\"},{\"name\":\"down\",\"on\":[{\"events\":\"mousedown\",\"update\":\"xy()\"}],\"value\":null},{\"name\":\"xcur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(xdom)\"}],\"value\":null},{\"name\":\"ycur\",\"on\":[{\"events\":\"mousedown\",\"update\":\"slice(ydom)\"}],\"value\":null},{\"name\":\"delta\",\"on\":[{\"events\":[{\"between\":[{\"type\":\"mousedown\"},{\"source\":\"window\",\"type\":\"mouseup\"}],\"consume\":true,\"source\":\"window\",\"type\":\"mousemove\"}],\"update\":\"down ? [down[0]-x(), down[1]-y()] : [0,0]\"}],\"value\":[0,0]},{\"name\":\"anchor\",\"on\":[{\"events\":\"wheel\",\"update\":\"[invert('xscale', x()), invert('yscale', y())]\"}],\"value\":[0,0]},{\"name\":\"xext\",\"update\":\"[0,width]\"},{\"name\":\"yext\",\"update\":\"[0,height]\"},{\"name\":\"zoom\",\"on\":[{\"events\":\"wheel!\",\"force\":true,\"update\":\"pow(1.001, event.deltaY * pow(16, event.deltaMode))\"}],\"value\":1},{\"name\":\"xdom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[xcur[0] + span(xcur) * delta[0] / width, xcur[1] + span(xcur) * delta[0] / width]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[0] + (xdom[0] - anchor[0]) * zoom, anchor[0] + (xdom[1] - anchor[0]) * zoom]\"}],\"update\":\"[x_extent[0] - nodeWidth/ 2, x_extent[1] + nodeWidth / 2]\"},{\"name\":\"ydom\",\"on\":[{\"events\":{\"signal\":\"delta\"},\"update\":\"[ycur[0] + span(ycur) * delta[1] / height, ycur[1] + span(ycur) * delta[1] / height]\"},{\"events\":{\"signal\":\"zoom\"},\"update\":\"[anchor[1] + (ydom[0] - anchor[1]) * zoom, anchor[1] + (ydom[1] - anchor[1]) * zoom]\"}],\"update\":\"[y_extent[0] - nodeHeight, y_extent[1] + nodeHeight/3]\"},{\"name\":\"scaledNodeWidth\",\"update\":\"(nodeWidth/ span(xdom))*width\"},{\"name\":\"scaledNodeHeight\",\"update\":\"abs(nodeHeight/ span(ydom))*height\"},{\"name\":\"scaledLimit\",\"update\":\"(20/ span(xdom))*width\"},{\"name\":\"spaceBetweenLevels\",\"value\":100},{\"name\":\"spaceBetweenNodes\",\"value\":10},{\"name\":\"nodeWidth\",\"value\":100},{\"name\":\"nodeHeight\",\"value\":45},{\"name\":\"startingDepth\",\"on\":[{\"events\":{\"throttle\":0,\"type\":\"timer\"},\"update\":\"-1\"}],\"value\":4}],\"width\":300}","ref":"EXGBoost.Plotting.Styles.html"},{"type":"module","title":"EXGBoost.Booster","doc":"A Booster is the main object used for training and prediction. It is a wrapper around the\nunderlying XGBoost C API.  Booster have three main concepts for tracking associated data:\nparameters, attributes, and features. Parameters are used to configure the Booster and are\nfrom a set of valid options (such as `tree_depth` and `eta` -- refer to `EXGBoost.Parameters` for full list).\nAttributes are user-provided key-value pairs that are assigned to a Booster (such as `best_iteration` and `best_score`).\nFeatures are used to track the metadata associated with the features used in training (such as `feature_names` and `feature_types`).","ref":"EXGBoost.Booster.html"},{"type":"module","title":"Training - EXGBoost.Booster","doc":"When using `EXGBoost.train/2`, a Booster is created and trained automatically with the given parameters.\nIf you need more control over the training process, please refer to `EXGBoost.Training.Callback` for\nguidance on how to inject custom logic into the training process.","ref":"EXGBoost.Booster.html#module-training"},{"type":"module","title":"Creation - EXGBoost.Booster","doc":"A Booster can be created using `EXGBoost.Booster.booster` from a list of DMatrices, a single DMatrix, or\nanother Booster. If a list of DMatrices is provided, the first DMatrix is used as the training\ndata and the rest are used for evaluation. If a single DMatrix is provided, it is used as the\ntraining data. If another Booster is provided, it is copied and returned as a new Booster with\nthe same configuration -- if params are provided, they will override the configuration of the\ncopied Booster.","ref":"EXGBoost.Booster.html#module-creation"},{"type":"module","title":"Serialization - EXGBoost.Booster","doc":"A Booster can be serialized to a file using `EXGBoost.Booster.save` and loaded from a file\nusing `EXGBoost.Booster.load`. The file format can be specified using the `:format` option\nwhich can be either `:json` or `:ubj`. The default is `:json`. If the file already exists, it will\nbe overwritten by default.  Boosters can either be serialized to a file or to a binary string.\nBoosters can be serialized in three different ways: configuration only, configuration and model, or\nmodel only. Any function that uses the `to` and `from` `buffer` functions will serialize the Booster\nto a binary string. The `to` and `from` `file` functions will serialize the Booster to a file.\nFunctions named with `weights` will serialize the model weights only. Functions named with `config` will\nserialize the configuration only. Functions that specify `model` will serialize both the model weights\nand the configuration.\n\n#","ref":"EXGBoost.Booster.html#module-serialization"},{"type":"module","title":"Output Formats - EXGBoost.Booster","doc":"- `file` - Save to a file.\n- `buffer` - Save to a binary string.\n\n#","ref":"EXGBoost.Booster.html#module-output-formats"},{"type":"module","title":"Output Contents - EXGBoost.Booster","doc":"- `config` - Save the configuration only.\n- `weights` - Save the model weights only.\n- `model` - Save both the model weights and the configuration.","ref":"EXGBoost.Booster.html#module-output-contents"},{"type":"function","title":"EXGBoost.Booster.boost/4","doc":"Boost the booster for one iteration, with customized gradient statistics.","ref":"EXGBoost.Booster.html#boost/4"},{"type":"function","title":"EXGBoost.Booster.booster/2","doc":"Create a new Booster.\n\nA Booster can be created from a list of DMatrices, a single DMatrix, or\nanother Booster. If a list of DMatrices is provided, the first DMatrix is used as the training\ndata and the rest are used for evaluation. If a single DMatrix is provided, it is used as the\ntraining data. If another Booster is provided, it is copied and returned as a new Booster with\nthe same configuration -- if params are provided, they will override the configuration of the\ncopied Booster.","ref":"EXGBoost.Booster.html#booster/2"},{"type":"function","title":"Options - EXGBoost.Booster.booster/2","doc":"Refer to `EXGBoost.Parameters` for a list of valid options.","ref":"EXGBoost.Booster.html#booster/2-options"},{"type":"function","title":"EXGBoost.Booster.eval/3","doc":"Evaluate the model on the given data.","ref":"EXGBoost.Booster.html#eval/3"},{"type":"function","title":"Options - EXGBoost.Booster.eval/3","doc":"* `:name` - The name of the dataset.\n\n  * `:iteration` - The current iteration number.\n\n  Returns the evaluation result string.","ref":"EXGBoost.Booster.html#eval/3-options"},{"type":"function","title":"EXGBoost.Booster.eval_set/4","doc":"Evaluate a set of data.","ref":"EXGBoost.Booster.html#eval_set/4"},{"type":"function","title":"Options - EXGBoost.Booster.eval_set/4","doc":"* `iteration` - Current iteration.\n* `feval` - Custom evaluation function.\n\nReturns the resulting metrics as a list of 2-tuples in the form of {eval_metric, value}.","ref":"EXGBoost.Booster.html#eval_set/4-options"},{"type":"function","title":"EXGBoost.Booster.get_attr/2","doc":"Get the attribute value for the given key.","ref":"EXGBoost.Booster.html#get_attr/2"},{"type":"function","title":"EXGBoost.Booster.get_attrs/1","doc":"Get the attribute names for the booster.","ref":"EXGBoost.Booster.html#get_attrs/1"},{"type":"function","title":"EXGBoost.Booster.get_best_iteration/1","doc":"Get the best iteration for the booster.","ref":"EXGBoost.Booster.html#get_best_iteration/1"},{"type":"function","title":"EXGBoost.Booster.get_boosted_rounds/1","doc":"Get the number of boosted rounds for the booster.","ref":"EXGBoost.Booster.html#get_boosted_rounds/1"},{"type":"function","title":"EXGBoost.Booster.get_dump/2","doc":"Get a formatted representation of the Booster's model.","ref":"EXGBoost.Booster.html#get_dump/2"},{"type":"function","title":"Options - EXGBoost.Booster.get_dump/2","doc":"* `:fmap` (`t:String.t/0`) - The path to the file containing the feature map. The default value is `\"\"`.\n\n* `:with_stats` (`t:boolean/0`) - Whether or not to include the statistics in the dump. The default value is `false`.\n\n* `:format` - The format to dump to. Can be either `:json` or `:text`. The default value is `:text`.","ref":"EXGBoost.Booster.html#get_dump/2-options"},{"type":"function","title":"EXGBoost.Booster.get_feature_names/1","doc":"Get the names of the features for the booster.","ref":"EXGBoost.Booster.html#get_feature_names/1"},{"type":"function","title":"EXGBoost.Booster.get_feature_types/1","doc":"Get the type for each feature in the booster","ref":"EXGBoost.Booster.html#get_feature_types/1"},{"type":"function","title":"EXGBoost.Booster.get_num_features/1","doc":"Get the number of features for the booster.","ref":"EXGBoost.Booster.html#get_num_features/1"},{"type":"function","title":"EXGBoost.Booster.load/2","doc":"Load a Booster from the specified source. If a Booster is provided, the model will be loaded into\nthat Booster. Otherwise, a new Booster will be created. If a Booster is provided, model parameters\nwill be merged with the existing Booster's parameters using Map.merge/2, where the parameters\nof the provided Booster take precedence.","ref":"EXGBoost.Booster.html#load/2"},{"type":"function","title":"Options - EXGBoost.Booster.load/2","doc":"* `:from` - The input format. Can be either `:file` or `:buffer`. The default value is `:file`.\n\n* `:deserialize` - The contents to deserialize. Can be either `:config`, `:weights`, or `:model`. The default value is `:model`.\n\n* `:booster` (struct of type EXGBoost.Booster) - The Booster to load the model into. If not provided, a new Booster will be created.","ref":"EXGBoost.Booster.html#load/2-options"},{"type":"function","title":"EXGBoost.Booster.predict/3","doc":"","ref":"EXGBoost.Booster.html#predict/3"},{"type":"function","title":"EXGBoost.Booster.save/2","doc":"Save a Booster to the specified source.","ref":"EXGBoost.Booster.html#save/2"},{"type":"function","title":"Options - EXGBoost.Booster.save/2","doc":"* `:to` - The output format. Can be either `:file` or `:buffer`. The default value is `:file`.\n\n* `:path` (`t:String.t/0`) - The path to the file to save to. Required if `to` is `:file`.\n\n* `:serialize` - The contents to serialize. Can be either `:config`, `:weights`, or `:model`. The default value is `:model`.\n\n* `:format` - The format to serialize to. Can be either `:json` or `:ubj`. The default value is `:json`.\n\n* `:overwrite` (`t:boolean/0`) - Whether or not to overwrite the file if it already exists. The default value is `false`.","ref":"EXGBoost.Booster.html#save/2-options"},{"type":"function","title":"EXGBoost.Booster.set_attr/2","doc":"Set attributes for booster.\n\nKey value pairs are passed as options. You can set an existing key to :nil to\ndelete the attribute. Returns the booster.","ref":"EXGBoost.Booster.html#set_attr/2"},{"type":"function","title":"EXGBoost.Booster.set_params/2","doc":"Set parameters for booster. The parameters are passed as a keyword list. Please refer to\n`EXGBoost.Parameters` for a full list of parameters. Parameters can be set multiple times\nby passng a list of values for a given parameter. For example, `set_params(booster, eval_metric: [:rmse, :auc])`.\nAccepts both atoms and strings as keys. Nested keyword lists will simply be treated as more key-value pairs\nto be set. Returns the booster.","ref":"EXGBoost.Booster.html#set_params/2"},{"type":"function","title":"EXGBoost.Booster.slice/4","doc":"Slice a model using boosting index. The slice m:n indicates taking all\ntrees that were fit during the boosting rounds m, (m+1), (m+2), …, (n-1).","ref":"EXGBoost.Booster.html#slice/4"},{"type":"function","title":"EXGBoost.Booster.update/4","doc":"Update for one iteration, with objective function calculated internally.\n\nIf an objective function is provided rather than a number of iterations, this\nupdates for one iteration, with objective function defined by the user.\n\nSee [Custom Objective](https://xgboost.readthedocs.io/en/latest/tutorials/custom_metric_obj.html) for details.","ref":"EXGBoost.Booster.html#update/4"},{"type":"type","title":"EXGBoost.Booster.t/0","doc":"","ref":"EXGBoost.Booster.html#t:t/0"},{"type":"module","title":"EXGBoost.Parameters","doc":"Parameters are used to configure the training process and the booster.","ref":"EXGBoost.Parameters.html"},{"type":"module","title":"Global Parameters - EXGBoost.Parameters","doc":"You can set the following params either using a global application config (preferred)\nor using the `EXGBoost.set_config/1` function. The global config is set using the `:exgboost` key.\nNote that using the `EXGBoost.set_config/1` function will override the global config for the\ncurrent instance of the application.\n\n```elixir\nconfig :exgboost,\n  verbosity: :info,\n  use_rmm: true,\n```\n* `:verbosity` - Verbosity of printing messages. Valid values are:\n  `:silent`, `:warning`, `:info`, `:debug`. The default value is `:silent`.\n\n* `:use_rmm` (`t:boolean/0`) - Whether to use RAPIDS Memory Manager for memory allocation.\n  This option is only applicable when XGBoost is built (compiled)\n  with the RMM plugin enabled. Valid values are `true` and `false`. The default value is `false`.","ref":"EXGBoost.Parameters.html#module-global-parameters"},{"type":"module","title":"General Parameters - EXGBoost.Parameters","doc":"* `:booster` - Which booster to use. Valid values are `:gbtree`, `:gblinear`, `:dart`\n    * `:gbtree` - tree-based models\n    * `:gblinear` - linear models\n    * `:dart` - tree-based models with dropouts The default value is `:gbtree`.\n\n* `:device` - Device for XGBoost to run. User can set it to one of the following values:\n    * `:cpu` - Use a CPU.\n    * `:cuda` - Use a GPU (CUDA device).\n    * `{:cuda, ordinal}` -  `ordinal` is an integer that specifies the ordinal of the GPU (which GPU do you want to use if you have more than one devices).\n    * `:gpu` - Default GPU device selection from the list of available and supported devices. Only `cuda` devices are supported currently.\n    * `{:gpu, ordinal}` - Default GPU device selection from the list of available and supported devices. Only `cuda` devices are supported currently.\n\n    For more information about GPU acceleration, see [XGBoost GPU Support](https://xgboost.readthedocs.io/en/stable/gpu/index.html). In distributed environments, ordinal selection is handled by distributed frameworks instead of XGBoost. As a result, using `{:cuda, ordinal}` will result in an error. Use `:cuda` instead.\n\n  The default value is `:cpu`.\n\n* `:verbosity` - Verbosity of printing messages. Valid values are:\n  `:silent`, `:warning`, `:info`, `:debug` The default value is `:silent`.\n\n* `:validate_parameters` (`t:boolean/0`) - Whether to perform validation of parameters. If set to `true`, an error\n  will be raised if an invalid parameter is passed to the booster, and\n  EXGBoost will take care of formatting all parameters to the expected\n  input of XGBoost. If set to `false`, the user is responsible for ensuring\n  that all parameters are valid strings which is what XGBoost is expecting. The default value is `true`.\n\n* `:nthread` (`t:non_neg_integer/0`) - Number of threads to use for training and prediction. If `0`, then the\n  number of threads is set to the number of cores.  This can be set globally\n  using the `:exgboost` application environment variable `:nthread`\n  or on a per booster basis.  If set globally, the value will be used for\n  all boosters unless overridden by a specific booster.\n  To set the number of threads globally, add the following to your `config.exs`:\n  `config :exgboost, nthread: n`. The default value is `0`.\n\n* `:disable_default_eval_metric` (`t:boolean/0`) - Whether to disable the default metric. If set to `true`, then the default\n  metric is not used for evaluation. This is useful when using custom\n  evaluation metrics. The default value is `false`.\n\n* `:num_features` (`t:non_neg_integer/0`) - Feature dimension used in boosting, set to maximum dimension of the feature","ref":"EXGBoost.Parameters.html#module-general-parameters"},{"type":"module","title":"Tree Booster Parameters - EXGBoost.Parameters","doc":"* `:eta` - Step size shrinkage used in update to prevents overfitting. After each\n  boosting step, we can directly get the weights of new features. and `eta`\n  actually shrinks the feature weights to make the boosting process more\n  conservative. Valid range is [0,1]. The default value is `0.3`.\n\n* `:gamma` - Minimum loss reduction required to make a further partition on a leaf node\n  of the tree. The larger `gamma` is, the more conservative the algorithm will\n  be. Valid range is [0, $\\infty$]. The default value is `0.0`.\n\n* `:max_depth` (`t:non_neg_integer/0`) - Maximum depth of a tree. Increasing this value will make the model more complex\n  and more likely to overfit. `0` indicates no limit on depth. Beware that XGBoost\n  aggressively consumes memory when training a deep tree. `exact` tree method requires\n  non-zero value. The default value is `6`.\n\n* `:min_child_weight` - Minimum sum of instance weight (hessian) needed in a child. If the tree partition\n  step results in a leaf node with the sum of instance weight less than `min_child_weight`,\n  then the building process will give up further partitioning. In linear regression task,\n  this simply corresponds to minimum number of instances needed to be in each node.\n  The larger `min_child_weight` is, the more conservative the algorithm will be.\n  Valid range is [0, $\\infty$]. The default value is `1`.\n\n* `:max_delta_step` - Maximum delta step we allow each tree's weight estimation to be. If the value is set\n  to `0`, it means there is no constraint. If it is set to a positive value, it can help\n  making the update step more conservative. Usually this parameter is not needed, but it\n  might help in logistic regression when class is extremely imbalanced. Set it to value of\n  1-10 might help control the update. Valid range is [0, $\\infty$]. The default value is `0`.\n\n* `:subsample` - Subsample ratio of the training instance. Setting it to `0.5` means that XGBoost\n  randomly collected half of the data instances to grow trees and this will prevent\n  overfitting. Subsampling will occur once in every boosting iteration. Valid range is (0, 1]. The default value is `1.0`.\n\n* `:sampling_method` - The method to use to sample the training instances.\n    * `:uniform` - each training instance has an equal probability of being selected.\n      Typically set `:subsample` $\\ge$ 0.5 for good results. The default value is `:uniform`.\n\n* `:colsample_by` - This is a family of parameters for subsampling of columns.\n  All `colsample_by` parameters have a range of `(0, 1]`, the default value of `1`, and specify the fraction of columns to be subsampled.\n  `colsample_by` parameters work cumulatively. For instance, the combination\n  `col_sampleby: [tree: 0.5, level: 0.5, node: 0.5]` with `64` features will leave `8`.\n    * `:tree` - The subsample ratio of columns when constructing each tree. Subsampling occurs once for every tree constructed. Valid range is (0, 1]. The default value is `1`.\n    * `:level` - The subsample ratio of columns for each level. Subsampling occurs once for every new depth level reached in a tree. Columns are subsampled from the set of columns chosen for the current tree. Valid range is (0, 1]. The default value is `1`.\n    * `:node` - The subsample ratio of columns for each node (split). Subsampling occurs once every time a new split is evaluated. Columns are subsampled from the set of columns chosen for the current level. Valid range is (0, 1]. The default value is `1`.\n\n* `:lambda` - L2 regularization term on weights. Increasing this value will make model more conservative.\n  Valid range is [0, $\\infty$]. The default value is `1`.\n\n* `:alpha` - L1 regularization term on weights. Increasing this value will make model more conservative.\n  Valid range is [0, $\\infty$]. The default value is `0`.\n\n* `:tree_method` - The tree construction algorithm used in XGBoost.\n  This is a combination of commonly used updaters. For other updaters like\n  `refresh`, set the parameter `updater` directly.\n    * `:auto` - Use heuristic to choose the fastest method.\n      * For small dataset, exact greedy (`exact`) will be used.\n      * For larger dataset, approximate algorithm (`approx`) will be chosen. It’s recommended to try\n        `hist` for higher performance with large dataset.\n      * Because old behavior is always use exact greedy in single machine, user will get a message\n        when approximate algorithm is chosen to notify this choice.\n    * `:exact` - Exact greedy algorithm. Enumerates all split candidates.\n    * `:approx` - Approximate greedy algorithm using sketching and histogram.\n    * `:hist` - Faster histogram optimized approximate greedy algorithm. The default value is `:auto`.\n\n* `:scale_pos_weight` (`t:float/0`) - Control the balance of positive and negative weights, useful for unbalanced classes.\n  A typical value to consider: `sum(negative instances) / sum(positive instances)`. The default value is `1.0`.\n\n* `:updater` - A list defining the sequence of tree updaters to run, providing a\n  modular way to construct and to modify the trees. This is an advanced parameter that\n  is usually set automatically, depending on some other parameters. However, it could be\n  also set explicitly by a user. The following updaters exist:\n    * `:grow_colmaker` - non-distributed column-based construction of trees.\n    * `:grow_histmaker` - distributed tree construction with row-based data splitting based on global proposal of histogram counting.\n    * `:grow_quantile_histmaker` - Grow tree using quantized histogram.\n    * `:sync` - synchronizes trees in all distributed nodes.\n    * `:refresh` - refreshes tree’s statistics and/or leaf values based on the current data. Note that no random subsampling of data rows is performed.\n    * `:prune` - prunes the splits where loss < min_split_loss (or gamma) and nodes that have depth greater than max_depth.\n\n* `:refresh_leaf` - This is a parameter of the refresh updater. When this flag is 1,\n  tree leafs as well as tree nodes’ stats are updated. When it is 0, only node stats are updated. The default value is `1`.\n\n* `:process_type` - The type of boosting process to run\n    * `:default` - The normal boosting process which creates new trees.\n    * `:update` - Starts from an existing model and only updates its trees. In each boosting iteration,\n        a tree from the initial model is taken, a specified sequence of updaters is run for that tree,\n        and a modified tree is added to the new model. The new model would have either the same or\n        smaller number of trees, depending on the number of boosting iterations performed. Currently,\n        the following built-in updaters could be meaningfully used with this process type:\n        `refresh`, `prune`. With `process_type: update`, one cannot use updaters that create new trees. The default value is `:default`.\n\n* `:grow_policy` - Controls a way new nodes are added to the tree. Currently supported only if `tree_method` is set\n  to `:hist` or `:approx`.\n    * `:depthwise` - split at nodes closest to the root.\n    * `:lossguide` - split at nodes with highest loss change. The default value is `:depthwise`.\n\n* `:max_leaves` (`t:non_neg_integer/0`) - Maximum number of nodes to be added. Not used by `exact` tree method. The default value is `0`.\n\n* `:max_bin` (`t:pos_integer/0`) - Maximum number of discrete bins to bucket continuous features. Used only if\n  `tree_method` is set to `:hist` or `:approx`.\n  Maximum number of discrete bins to bucket continuous features.\n  Increasing this number improves the optimality of splits at the cost of higher computation time. The default value is `256`.\n\n* `:predictor` - The type of predictor algorithm to use. Provides the same results but allows the use of GPU or CPU.\n    * `:auto` - Configure predictor based on heuristics.\n    * `:cpu_predictor` - Multicore CPU prediction algorithm. The default value is `:auto`.\n\n* `:num_parallel_tree` (`t:non_neg_integer/0`) - Number of parallel trees constructed during each iteration. This option is used to support boosted random forest. The default value is `1`.\n\n* `:monotone_constraints` - Constraint of variable monotonicity. See [Monotonic Constraints](https://xgboost.readthedocs.io/en/latest/tutorials/monotonic.html) for more information.\n\n* `:interaction_constraints` (list of list of `t:integer/0`) - Constraints for interaction representing permitted interactions. The constraints must be specified in the\n  form of a nested list, e.g. `[[0, 1], [2, 3, 4]]`, where each inner list is a group of indices of features\n  that are allowed to interact with each other. See [Feature Interaction Constraints](https://xgboost.readthedocs.io/en/latest/tutorials/feature_interaction_constraint.html) for more information.\n\n* `:multi_strategy` - The strategy used for training multi-target models, including multi-target regression and multi-class\n  classification. See [Multiple Outputs](https://xgboost.readthedocs.io/en/latest/tutorials/multioutput.html) for more information.\n    * `:one_output_per_tree` - One model for each target.\n    * `:multi_output_tree` - Use multi-target trees. The default value is `:one_output_per_tree`.\n\n* `:max_cached_hist_node` (`t:non_neg_integer/0`) - Maximum number of cached nodes for CPU histogram. For most of the cases this parameter should not be set except for growing deep trees on CPU. The default value is `65536`.","ref":"EXGBoost.Parameters.html#module-tree-booster-parameters"},{"type":"module","title":"Linear Booster Parameters - EXGBoost.Parameters","doc":"* `:lambda` (`t:float/0`) - L2 regularization term on weights. Increasing this value will make model more conservative. Normalised to number of training examples. The default value is `0.0`.\n\n* `:alpha` (`t:float/0`) - L1 regularization term on weights. Increasing this value will make model more conservative. Normalised to number of training examples. The default value is `0.0`.\n\n* `:updater` - Choice of algorithm to fit linear model\n    * `:shotgun` - Parallel coordinate descent algorithm based on shotgun algorithm. Uses ‘hogwild’ parallelism and therefore produces a nondeterministic solution on each run.\n    * `:coord_descent` - Ordinary coordinate descent algorithm. Also multithreaded but still produces a deterministic solution. The default value is `:shotgun`.\n\n* `:feature_selector` - Feature selection and ordering method\n    * `:cyclic` - Deterministic selection by cycling through features one at a time. Used with the `:shotgun` updater.\n    * `:shuffle` - Similar to `:cyclic` but with random feature shuffling prior to each update. Used with the `:shotgun` updater.\n    * `:random` - A random (with replacement) coordinate selector. Used with the `:coord_descent` updater.\n    * `:greedy` - Select coordinate with the greatest gradient magnitude. It has $O(num_feature^2)$ complexity. It is fully deterministic. It allows restricting the selection to `:top_k` features per group with the largest magnitude of univariate weight change, by setting the `:top_k` parameter. Doing so would reduce the complexity to $O(num_feature^{topk})$. Used by `:coord_descent` updater.\n    * `:thrifty` - Thrifty, approximately-greedy feature selector. Prior to cyclic updates, reorders features in descending magnitude of their univariate weight changes. This operation is multithreaded and is a linear complexity approximation of the quadratic greedy selection. It allows restricting the selection to `:top_k` features per group with the largest magnitude of univariate weight change, by setting the `:top_k` parameter. Used by `:coord_descent` updater. The default value is `:cyclic`.\n\n* `:top_k` (`t:non_neg_integer/0`) - The number of top features to select in `:greedy` and `:thrifty` feature selector. The value of 0 means using all the features. The default value is `0`.","ref":"EXGBoost.Parameters.html#module-linear-booster-parameters"},{"type":"module","title":"Dart Booster Parameters - EXGBoost.Parameters","doc":"* `:eta` - Step size shrinkage used in update to prevents overfitting. After each\n  boosting step, we can directly get the weights of new features. and `eta`\n  actually shrinks the feature weights to make the boosting process more\n  conservative. Valid range is [0,1]. The default value is `0.3`.\n\n* `:gamma` - Minimum loss reduction required to make a further partition on a leaf node\n  of the tree. The larger `gamma` is, the more conservative the algorithm will\n  be. Valid range is [0, $\\infty$]. The default value is `0.0`.\n\n* `:max_depth` (`t:non_neg_integer/0`) - Maximum depth of a tree. Increasing this value will make the model more complex\n  and more likely to overfit. `0` indicates no limit on depth. Beware that XGBoost\n  aggressively consumes memory when training a deep tree. `exact` tree method requires\n  non-zero value. The default value is `6`.\n\n* `:min_child_weight` - Minimum sum of instance weight (hessian) needed in a child. If the tree partition\n  step results in a leaf node with the sum of instance weight less than `min_child_weight`,\n  then the building process will give up further partitioning. In linear regression task,\n  this simply corresponds to minimum number of instances needed to be in each node.\n  The larger `min_child_weight` is, the more conservative the algorithm will be.\n  Valid range is [0, $\\infty$]. The default value is `1`.\n\n* `:max_delta_step` - Maximum delta step we allow each tree's weight estimation to be. If the value is set\n  to `0`, it means there is no constraint. If it is set to a positive value, it can help\n  making the update step more conservative. Usually this parameter is not needed, but it\n  might help in logistic regression when class is extremely imbalanced. Set it to value of\n  1-10 might help control the update. Valid range is [0, $\\infty$]. The default value is `0`.\n\n* `:subsample` - Subsample ratio of the training instance. Setting it to `0.5` means that XGBoost\n  randomly collected half of the data instances to grow trees and this will prevent\n  overfitting. Subsampling will occur once in every boosting iteration. Valid range is (0, 1]. The default value is `1.0`.\n\n* `:sampling_method` - The method to use to sample the training instances.\n    * `:uniform` - each training instance has an equal probability of being selected.\n      Typically set `:subsample` $\\ge$ 0.5 for good results. The default value is `:uniform`.\n\n* `:colsample_by` - This is a family of parameters for subsampling of columns.\n  All `colsample_by` parameters have a range of `(0, 1]`, the default value of `1`, and specify the fraction of columns to be subsampled.\n  `colsample_by` parameters work cumulatively. For instance, the combination\n  `col_sampleby: [tree: 0.5, level: 0.5, node: 0.5]` with `64` features will leave `8`.\n    * `:tree` - The subsample ratio of columns when constructing each tree. Subsampling occurs once for every tree constructed. Valid range is (0, 1]. The default value is `1`.\n    * `:level` - The subsample ratio of columns for each level. Subsampling occurs once for every new depth level reached in a tree. Columns are subsampled from the set of columns chosen for the current tree. Valid range is (0, 1]. The default value is `1`.\n    * `:node` - The subsample ratio of columns for each node (split). Subsampling occurs once every time a new split is evaluated. Columns are subsampled from the set of columns chosen for the current level. Valid range is (0, 1]. The default value is `1`.\n\n* `:lambda` - L2 regularization term on weights. Increasing this value will make model more conservative.\n  Valid range is [0, $\\infty$]. The default value is `1`.\n\n* `:alpha` - L1 regularization term on weights. Increasing this value will make model more conservative.\n  Valid range is [0, $\\infty$]. The default value is `0`.\n\n* `:tree_method` - The tree construction algorithm used in XGBoost.\n  This is a combination of commonly used updaters. For other updaters like\n  `refresh`, set the parameter `updater` directly.\n    * `:auto` - Use heuristic to choose the fastest method.\n      * For small dataset, exact greedy (`exact`) will be used.\n      * For larger dataset, approximate algorithm (`approx`) will be chosen. It’s recommended to try\n        `hist` for higher performance with large dataset.\n      * Because old behavior is always use exact greedy in single machine, user will get a message\n        when approximate algorithm is chosen to notify this choice.\n    * `:exact` - Exact greedy algorithm. Enumerates all split candidates.\n    * `:approx` - Approximate greedy algorithm using sketching and histogram.\n    * `:hist` - Faster histogram optimized approximate greedy algorithm. The default value is `:auto`.\n\n* `:scale_pos_weight` (`t:float/0`) - Control the balance of positive and negative weights, useful for unbalanced classes.\n  A typical value to consider: `sum(negative instances) / sum(positive instances)`. The default value is `1.0`.\n\n* `:updater` - A list defining the sequence of tree updaters to run, providing a\n  modular way to construct and to modify the trees. This is an advanced parameter that\n  is usually set automatically, depending on some other parameters. However, it could be\n  also set explicitly by a user. The following updaters exist:\n    * `:grow_colmaker` - non-distributed column-based construction of trees.\n    * `:grow_histmaker` - distributed tree construction with row-based data splitting based on global proposal of histogram counting.\n    * `:grow_quantile_histmaker` - Grow tree using quantized histogram.\n    * `:sync` - synchronizes trees in all distributed nodes.\n    * `:refresh` - refreshes tree’s statistics and/or leaf values based on the current data. Note that no random subsampling of data rows is performed.\n    * `:prune` - prunes the splits where loss < min_split_loss (or gamma) and nodes that have depth greater than max_depth.\n\n* `:refresh_leaf` - This is a parameter of the refresh updater. When this flag is 1,\n  tree leafs as well as tree nodes’ stats are updated. When it is 0, only node stats are updated. The default value is `1`.\n\n* `:process_type` - The type of boosting process to run\n    * `:default` - The normal boosting process which creates new trees.\n    * `:update` - Starts from an existing model and only updates its trees. In each boosting iteration,\n        a tree from the initial model is taken, a specified sequence of updaters is run for that tree,\n        and a modified tree is added to the new model. The new model would have either the same or\n        smaller number of trees, depending on the number of boosting iterations performed. Currently,\n        the following built-in updaters could be meaningfully used with this process type:\n        `refresh`, `prune`. With `process_type: update`, one cannot use updaters that create new trees. The default value is `:default`.\n\n* `:grow_policy` - Controls a way new nodes are added to the tree. Currently supported only if `tree_method` is set\n  to `:hist` or `:approx`.\n    * `:depthwise` - split at nodes closest to the root.\n    * `:lossguide` - split at nodes with highest loss change. The default value is `:depthwise`.\n\n* `:max_leaves` (`t:non_neg_integer/0`) - Maximum number of nodes to be added. Not used by `exact` tree method. The default value is `0`.\n\n* `:max_bin` (`t:pos_integer/0`) - Maximum number of discrete bins to bucket continuous features. Used only if\n  `tree_method` is set to `:hist` or `:approx`.\n  Maximum number of discrete bins to bucket continuous features.\n  Increasing this number improves the optimality of splits at the cost of higher computation time. The default value is `256`.\n\n* `:predictor` - The type of predictor algorithm to use. Provides the same results but allows the use of GPU or CPU.\n    * `:auto` - Configure predictor based on heuristics.\n    * `:cpu_predictor` - Multicore CPU prediction algorithm. The default value is `:auto`.\n\n* `:num_parallel_tree` (`t:non_neg_integer/0`) - Number of parallel trees constructed during each iteration. This option is used to support boosted random forest. The default value is `1`.\n\n* `:monotone_constraints` - Constraint of variable monotonicity. See [Monotonic Constraints](https://xgboost.readthedocs.io/en/latest/tutorials/monotonic.html) for more information.\n\n* `:interaction_constraints` (list of list of `t:integer/0`) - Constraints for interaction representing permitted interactions. The constraints must be specified in the\n  form of a nested list, e.g. `[[0, 1], [2, 3, 4]]`, where each inner list is a group of indices of features\n  that are allowed to interact with each other. See [Feature Interaction Constraints](https://xgboost.readthedocs.io/en/latest/tutorials/feature_interaction_constraint.html) for more information.\n\n* `:multi_strategy` - The strategy used for training multi-target models, including multi-target regression and multi-class\n  classification. See [Multiple Outputs](https://xgboost.readthedocs.io/en/latest/tutorials/multioutput.html) for more information.\n    * `:one_output_per_tree` - One model for each target.\n    * `:multi_output_tree` - Use multi-target trees. The default value is `:one_output_per_tree`.\n\n* `:max_cached_hist_node` (`t:non_neg_integer/0`) - Maximum number of cached nodes for CPU histogram. For most of the cases this parameter should not be set except for growing deep trees on CPU. The default value is `65536`.\n\n* `:sample_type` - Type of sampling algorithm.\n     * `:uniform` - Dropped trees are selected uniformly.\n     * `:weighted` - Dropped trees are selected in proportion to weight. The default value is `:uniform`.\n\n* `:normalize_type` - Type of normalization algorithm.\n     * `:tree` - New trees have the same weight of each of dropped trees.\n         * Weight of new trees are `1 / (k + learning_rate)`.\n         * Dropped trees are scaled by a factor of `k / (k + learning_rate)`.\n     * `:forest` - New trees have the same weight of sum of dropped trees (forest).\n         * Weight of new trees are 1 / (1 + learning_rate).\n         * Dropped trees are scaled by a factor of 1 / (1 + learning_rate). The default value is `:tree`.\n\n* `:rate_drop` - Dropout rate (a fraction of previous trees to drop during the dropout). Valid range is [0, 1]. The default value is `0.0`.\n\n* `:one_drop` - When this flag is enabled, at least one tree is always dropped during the dropout (allows Binomial-plus-one or epsilon-dropout from the original DART paper). The default value is `0`.\n\n* `:skip_drop` - Probability of skipping the dropout procedure during a boosting iteration. Valid range is [0, 1].\n     * If a dropout is skipped, new trees are added in the same manner as gbtree.\n     * **Note** that non-zero skip_drop has higher priority than rate_drop or one_drop. The default value is `0.0`.","ref":"EXGBoost.Parameters.html#module-dart-booster-parameters"},{"type":"module","title":"Learning Task Parameters - EXGBoost.Parameters","doc":"* `:objective` - Specify the learning task and the corresponding learning objective. The objective options are:\n    * `:reg_squarederror` - regression with squared loss.\n    * `:reg_squaredlogerror` - regression with squared log loss $\\frac{1}{2}[\\log (pred + 1) - \\log (label + 1)]^2$. All input labels are required to be greater than `-1`. Also, see metric rmsle for possible issue with this objective.\n    * `:reg_logistic` - logistic regression.\n    * `:reg_pseudohubererror` - regression with Pseudo Huber loss, a twice differentiable alternative to absolute loss.\n    * `:reg_absoluteerror` - Regression with `L1` error. When tree model is used, leaf value is refreshed after tree construction. If used in distributed training, the leaf value is calculated as the mean value from all workers, which is not guaranteed to be optimal.\n    * `:reg_quantileerror` - Quantile loss, also known as pinball loss. See later sections for its parameter and Quantile Regression for a worked example.\n    * `:binary_logistic` - logistic regression for binary classification, output probability\n    * `:binary_logitraw` - logistic regression for binary classification, output score before logistic transformation\n    * `:binary_hinge` - hinge loss for binary classification. This makes predictions of `0` or `1`, rather than producing probabilities.\n    * `:count_poisson` - Poisson regression for count data, output mean of Poisson distribution.\n        * `max_delta_step` is set to `0.7` by default in Poisson regression (used to safeguard optimization)\n    * `:survival_cox` - Cox regression for right censored survival time data (negative values are considered right censored). Note that predictions are returned on the hazard ratio scale (i.e., as `HR = exp(marginal_prediction)` in the proportional hazard function `h(t) = h0(t) * HR`).\n    * `:survival_aft` - Accelerated failure time model for censored survival time data. See [Survival Analysis with Accelerated Failure Time](https://xgboost.readthedocs.io/en/latest/tutorials/aft_survival_analysis.html) for details.\n    * `:multi_softmax` - set XGBoost to do multiclass classification using the softmax objective, you also need to set num_class(number of classes)\n    * `:multi_softprob` - same as softmax, but output a vector of ndata * nclass, which can be further reshaped to ndata * nclass matrix. The result contains predicted probability of each data point belonging to each class.\n    * `:rank_ndcg` - Use LambdaMART to perform pair-wise ranking where Normalized Discounted Cumulative Gain (NDCG) is maximized. This objective supports position debiasing for click data.\n    * `:rank_map` - Use LambdaMART to perform pair-wise ranking where Mean Average Precision (MAP) is maximized\n    * `:rank_pairwise` - Use LambdaRank to perform pair-wise ranking using the ranknet objective.\n    * `:reg_gamma` - gamma regression with log-link. Output is a mean of gamma distribution. It might be useful, e.g., for modeling insurance claims severity, or for any outcome that might be gamma-distributed.\n    * `:reg_tweedie` - Tweedie regression with log-link. It might be useful, e.g., for modeling total loss in insurance, or for any outcome that might be Tweedie-distributed. The default value is `:reg_squarederror`.\n\n* `:base_score` (`t:float/0`) - The initial prediction score of all instances, global bias\n  The parameter is automatically estimated for selected objectives before training. To disable the estimation, specify a real number argument.\n  For sufficient number of iterations, changing this value will not have too much effect.\n\n* `:eval_metric` - Evaluation metrics for validation data, a default metric will be assigned according to objective (`:rmse` for regression, and `:logloss` for classification, `mean average precision` for `:rank_map`, etc.)\n  User can add multiple evaluation metrics.\n    * `:rmse` - root mean square error\n    * `:rmsle` - root mean square log error. Default metric of `:reg_squaredlogerror` objective. This metric reduces errors generated by outliers in dataset. But because `log` function is employed, `:rmsle` might output nan when prediction value is less than `-1`. See `:reg_squaredlogerror` for other requirements.\n    * `:mae` - mean absolute error\n    * `:mape` - mean absolute percentage error\n    * `:mphe` - mean Pseudo Huber error. Default metric of `:reg_pseudohubererror` objective.\n    * `:logloss` - negative log-likelihood\n    * `:error` - Binary classification error rate. It is calculated as `#(wrong cases)/#(all cases)`. For the predictions, the evaluation will regard the instances with prediction value larger than `0.5` as positive instances, and the others as negative instances.\n    * `{:error,t}` - a different than `0.5` binary classification threshold value could be specified by providing a numerical value through `t`.\n    * `:merror` - Multiclass classification error rate. It is calculated as `#(wrong cases)/#(all cases)`.\n    * `:mlogloss` - Multiclass logloss.\n    * `:auc` - Receiver Operating Characteristic Area under the Curve. Available for classification and learning-to-rank tasks.\n      * When used with binary classification, the objective should be `:binary_logistic` or similar functions that work on probability.\n      * When used with multi-class classification, objective should be `:multi_softprob` instead of `:multi_softmax`, as the latter doesn’t output probability. Also the AUC is calculated by 1-vs-rest with reference class weighted by class prevalence.\n      * When used with LTR task, the AUC is computed by comparing pairs of documents to count correctly sorted pairs. This corresponds to pairwise learning to rank. The implementation has some issues with average AUC around groups and distributed workers not being well-defined.\n      * On a single machine the AUC calculation is exact. In a distributed environment the AUC is a weighted average over the AUC of training rows on each node - therefore, distributed AUC is an approximation sensitive to the distribution of data across workers. Use another metric in distributed environments if precision and reproducibility are important.\n      * When input dataset contains only negative or positive samples, the output is NaN. The behavior is implementation defined, for instance, scikit-learn returns  instead.\n    * `:aucpr` - Area under the PR curve. Available for classification and learning-to-rank tasks.\n    * `:ndcg` - Normalized Discounted Cumulative Gain\n    * `:map` - Mean Average Precision\n    * `{:ndcg,n}`, `{:map,n}` - `n` can be assigned as an integer to cut off the top positions in the lists for evaluation.\n    * `:inv_ndcg`, `:inv_map`, `{:inv_ndcg, n}`, `{:inv_map, n}` - In XGBoost, the NDCG and MAP evaluate the score of a list without any positive samples as `1`. By using the `:inv_` variant, we can ask XGBoost to evaluate these scores as `0` to be consistent under some conditions.\n    * `:poisson_nloglik` - negative log-likelihood for Poisson regression\n    * `:gamma_nloglik` - negative log-likelihood for gamma regression\n    * `:cox_nloglik` - negative partial log-likelihood for Cox proportional hazards regression\n    * `:gamma_deviance` - residual deviance for gamma regression\n    * `:tweedie_nloglik` - negative log-likelihood for Tweedie regression (at a specified value of the `:tweedie_variance_power` parameter). Must provide `:tweedie_variance_power` parameter.\n    * `{:tweedie_nloglik, rho}` - negative log-likelihood for Tweedie regression with `rho` denoting the `:tweedie_variance_power` parameter.\n    * `:aft_nloglik` - Negative log likelihood of Accelerated Failure Time model. See Survival Analysis with Accelerated Failure Time for details.\n    * `:interval_regression_accuracy` - Fraction of data points whose predicted labels fall in the interval-censored labels. Only applicable for interval-censored data. See Survival Analysis with Accelerated Failure Time for details.\n\n* `:seed` (`t:non_neg_integer/0`) - Random number seed. The default value is `0`.\n\n* `:set_seed_per_iteration` (`t:boolean/0`) - Seed PRNG determnisticly via iterator number. The default value is `false`.","ref":"EXGBoost.Parameters.html#module-learning-task-parameters"},{"type":"module","title":"Objective-Specific Parameters - EXGBoost.Parameters","doc":"#","ref":"EXGBoost.Parameters.html#module-objective-specific-parameters"},{"type":"module","title":"Tweedie Regression Parameters - EXGBoost.Parameters","doc":"* `:tweedie_variance_power` - Parameter that controls the variance of the Tweedie distribution `var(y) ~ E(y)^tweedie_variance_power`.\n  Valid range is (1,2).\n  Set closer to 2 to shift towards a gamma distribution.\n  Set closer to 1 to shift towards a Poisson distribution. The default value is `1.5`.\n\n\n\n#","ref":"EXGBoost.Parameters.html#module-tweedie-regression-parameters"},{"type":"module","title":"Pseudo-Huber Error Parameters - EXGBoost.Parameters","doc":"* `:huber_slope` - A parameter used for Pseudo-Huber loss. The default value is `1.0`.\n\n\n\n#","ref":"EXGBoost.Parameters.html#module-pseudo-huber-error-parameters"},{"type":"module","title":"Quantile Error Parameters - EXGBoost.Parameters","doc":"* `:quantile_alpha` - Targeted Quantile. The default value is `0.5`.\n\n\n\n#","ref":"EXGBoost.Parameters.html#module-quantile-error-parameters"},{"type":"module","title":"Survival Analysis Parameters - EXGBoost.Parameters","doc":"* `:aft_loss_distribution` - Probability Density Function, `:normal`, `:logistic`, or `:extreme`. The default value is `:normal`.\n\n\n\n#","ref":"EXGBoost.Parameters.html#module-survival-analysis-parameters"},{"type":"module","title":"Ranking Parameters - EXGBoost.Parameters","doc":"* `:lambdarank_pair_method` - How to construct pairs for pair-wise learning.\n    * `:mean` - Sample `lambdarank_num_pair_per_sample` pairs for each document in the query list.\n    * `:topk` - Focus on top-`lambdarank_num_pair_per_sample` documents. Construct pairs for each document at the top-`lambdarank_num_pair_per_sample` ranked by the model. The default value is `:mean`.\n\n* `:lambdarank_num_pair_per_sample` - It specifies the number of pairs sampled for each document when pair method is `:mean`, or the truncation level for queries when the pair method is `:topk`. For example, to train with `{:ndcg,6}`, set `:lambdarank_num_pair_per_sample` to `6` and `:lambdarank_pair_method` to `topk`. Valid range is [1, $\\infty$].\n\n* `:lambdarank_unbiased` (`t:boolean/0`) - Specify whether do we need to debias input click data. The default value is `false`.\n\n* `:lambdarank_bias_norm` - LP normalization for position debiasing, default is L2.\n  Only relevant when lambdarank_unbiased is set to true. The default value is `2.0`.\n\n* `:ndcg_exp_gain` (`t:boolean/0`) - Whether we should use exponential gain function for `NDCG`. There are two forms of gain function for `NDCG`,\n    one is using relevance value directly while the other is using `2^rel -1` to emphasize on retrieving\n    relevant documents. When `:ndcg_exp_gain` is `true` (the default), relevance degree cannot be greater than `31`. The default value is `true`.\n\n\n\n#","ref":"EXGBoost.Parameters.html#module-ranking-parameters"},{"type":"module","title":"Multi-Class Classification Parameters - EXGBoost.Parameters","doc":"* `:num_class` (`t:pos_integer/0`) - Number of classes.","ref":"EXGBoost.Parameters.html#module-multi-class-classification-parameters"},{"type":"function","title":"EXGBoost.Parameters.validate!/1","doc":"Validates the EXGBoost parameters and returns a keyword list of the validated parameters.","ref":"EXGBoost.Parameters.html#validate!/1"},{"type":"function","title":"EXGBoost.Parameters.validate_device/1","doc":"","ref":"EXGBoost.Parameters.html#validate_device/1"},{"type":"module","title":"EXGBoost.Training.Callback","doc":"Callbacks are a mechanism to hook into the training process and perform custom actions.\n\nCallbacks are structs with the following fields:\n* `event` - the event that triggers the callback\n* `fun` - the function to call when the callback is triggered\n* `name` - the name of the callback\n* `init_state` - the initial state of the callback\n\nThe following events are supported:\n* `:before_training` - called before the training starts\n* `:after_training` - called after the training ends\n* `:before_iteration` - called before each iteration\n* `:after_iteration` - called after each iteration\n\nThe callback function is called with the following arguments:\n* `state` - the current training state\n\nThe callback function should return one of the following:\n* `{:cont, state}` - continue training with the given state\n* `{:halt, state}` - stop training with the given state\n\nThe following callbacks are provided in the `EXGBoost.Training.Callback` module:\n* `lr_scheduler` - sets the learning rate for each iteration\n* `early_stop` - performs early stopping\n* `eval_metrics` - evaluates metrics on the training and evaluation sets\n* `eval_monitor` - prints evaluation metrics\n\nCallbacks can be added to the training process by passing them to `EXGBoost.Training.train/2`.","ref":"EXGBoost.Training.Callback.html"},{"type":"module","title":"Example - EXGBoost.Training.Callback","doc":"```elixir\n# Callback to perform setup before training\nsetup_fn = fn state ->\n  updated_state = put_in(state, [:meta_vars,:early_stop], %{best: 1, since_last_improvement: 0, mode: :max, patience: 5})\n  {:cont, updated_state}\nend\n\nsetup_callback = Callback.new(:before_training, setup_fn)\n```","ref":"EXGBoost.Training.Callback.html#module-example"},{"type":"function","title":"EXGBoost.Training.Callback.early_stop/1","doc":"A callback function that performs early stopping.\n\nRequires that the following exist in the `state` that is passed to the callback:\n\n* `target` is the metric to monitor for early stopping.  It must exist in the `metrics` that the\nstate contains.\n* `mode` is either `:min` or `:max` and indicates whether the metric should be\n   minimized or maximized.\n* `patience` is the number of iterations to wait for the metric to improve before stopping.\n* `since_last_improvement` is the number of iterations since the metric last improved.\n* `best` is the best value of the metric seen so far.","ref":"EXGBoost.Training.Callback.html#early_stop/1"},{"type":"function","title":"EXGBoost.Training.Callback.eval_metrics/1","doc":"A callback function that evaluates metrics on the training and evaluation sets.\n\nRequires that the following exist in the `state.meta_vars` that is passed to the callback:\n * eval_metrics:\n    * evals: a list of evaluation sets to evaluate metrics on\n    * filter: a function that takes a metric name and value and returns\n    true if the metric should be included in the results","ref":"EXGBoost.Training.Callback.html#eval_metrics/1"},{"type":"function","title":"EXGBoost.Training.Callback.lr_scheduler/1","doc":"A callback that sets the learning rate for each iteration.\n\nRequires that `learning_rates` either be a list of learning rates or a function that takes the\niteration number and returns a learning rate.  `learning_rates` must exist in the `state` that\nis passed to the callback.","ref":"EXGBoost.Training.Callback.html#lr_scheduler/1"},{"type":"function","title":"EXGBoost.Training.Callback.monitor_metrics/1","doc":"A callback function that prints evaluation metrics according to a period.\n\nRequires that the following exist in the `state.meta_vars` that is passed to the callback:\n * monitor_metrics:\n    * period: print metrics every `period` iterations\n    * filter: a function that takes a metric name and value and returns\n    true if the metric should be included in the results","ref":"EXGBoost.Training.Callback.html#monitor_metrics/1"},{"type":"function","title":"EXGBoost.Training.Callback.new/4","doc":"Factory for a new callback with an initial state.","ref":"EXGBoost.Training.Callback.html#new/4"},{"type":"function","title":"EXGBoost.Training.Callback.validate!/1","doc":"","ref":"EXGBoost.Training.Callback.html#validate!/1"},{"type":"type","title":"EXGBoost.Training.Callback.event/0","doc":"","ref":"EXGBoost.Training.Callback.html#t:event/0"},{"type":"type","title":"EXGBoost.Training.Callback.fun/0","doc":"","ref":"EXGBoost.Training.Callback.html#t:fun/0"},{"type":"extras","title":"Compiled Decision Trees Benchmark","doc":"# Compiled Decision Trees Benchmark\n\n```elixir\nMix.install([\n  {:scidata, \"~> 0.1\"},\n  {:exgboost, \"~> 0.4\"},\n  {:mockingjay, github: \"acalejos/mockingjay\"},\n  {:nx, \"~> 0.5\", override: true},\n  {:exla, \"~> 0.5\"},\n  {:scholar, \"~> 0.2\"},\n  {:benchee, \"~> 1.0\"}\n])\n```","ref":"compiled_benchmarks.html"},{"type":"extras","title":"Setup Dataset - Compiled Decision Trees Benchmark","doc":"```elixir\n{x, y} = Scidata.Iris.download()\ndata = Enum.zip(x, y) |> Enum.shuffle()\n{train, test} = Enum.split(data, ceil(length(data) * 0.8))\n{x_train, y_train} = Enum.unzip(train)\n{x_test, y_test} = Enum.unzip(test)\n\nx_train = Nx.tensor(x_train)\ny_train = Nx.tensor(y_train)\n\nx_test = Nx.tensor(x_test)\ny_test = Nx.tensor(y_test)\n```","ref":"compiled_benchmarks.html#setup-dataset"},{"type":"extras","title":"Gather Model / Prediction Functions - Compiled Decision Trees Benchmark","doc":"`EXGBoost.compile/1` will convert your trained `Booster` model into a set of tensor operations which can then be run on any of the `Nx` backends.\n\n```elixir\n# Get Baseline Model (XGBoost C API)\nmodel = EXGBoost.train(x_train, y_train, num_class: 3, objective: :multi_softprob)\n# Get Compiled Models w/ Binary Backend\nNx.Defn.default_options(compiler: Nx.Defn.Evaluator)\nNx.default_backend(Nx.BinaryBackend)\ngemm_predict = EXGBoost.compile(model, strategy: :gemm)\ngemm_jit_exla = EXLA.jit(gemm_predict)\ntree_trav_predict = EXGBoost.compile(model, strategy: :tree_traversal)\ntree_trav_jit_exla = EXLA.jit(tree_trav_predict)\nptt_predict = EXGBoost.compile(model, strategy: :perfect_tree_traversal)\nptt_jit_exla = EXLA.jit(ptt_predict)\n# Get Compiled Models w/ EXLA Backend\nNx.Defn.default_options(compiler: EXLA)\nNx.default_backend(EXLA.Backend)\ngemm_exla = EXGBoost.compile(model, strategy: :gemm)\ntree_trav_exla = EXGBoost.compile(model, strategy: :tree_traversal)\nptt_exla = EXGBoost.compile(model, strategy: :perfect_tree_traversal)\n\nfuncs = %{\n  \"Base\" => fn x -> EXGBoost.predict(model, x) end,\n  \"Compiled -- GEMM Strategy -- Binary Backend\" => fn x -> gemm_predict.(x) end,\n  \"Compiled -- Tree Traversal Strategy -- Binary Backend\" => fn x -> tree_trav_predict.(x) end,\n  \"Compiled -- Perfect Tree Traversal Strategy -- Binary Backend\" => fn x -> ptt_predict.(x) end,\n  \"Compiled -- GEMM Strategy -- EXLA Backend\" => fn x -> gemm_exla.(x) end,\n  \"Compiled -- Tree Traversal Strategy -- EXLA Backend\" => fn x -> tree_trav_exla.(x) end,\n  \"Compiled -- Perfect Tree Traversal Strategy -- EXLA Backend\" => fn x -> ptt_exla.(x) end,\n  \"Compiled -- GEMM Strategy -- EXLA Backend (JIT)\" => fn x -> gemm_jit_exla.(x) end,\n  \"Compiled -- Tree Traversal Strategy -- EXLA Backend (JIT)\" => fn x ->\n    tree_trav_jit_exla.(x)\n  end,\n  \"Compiled -- Perfect Tree Traversal Strategy -- EXLA Backend (JIT)\" => fn x ->\n    ptt_jit_exla.(x)\n  end\n}\n```","ref":"compiled_benchmarks.html#gather-model-prediction-functions"},{"type":"extras","title":"Run Time Benchmarks - Compiled Decision Trees Benchmark","doc":"```elixir\nbenches = Map.new(funcs, fn {k, v} -> {k, v.(x_train)} end)\n\nBenchee.run(benches,\n  time: 10,\n  memory_time: 2,\n  warmup: 5\n)\n```","ref":"compiled_benchmarks.html#run-time-benchmarks"},{"type":"extras","title":"Compare Accuracies - Compiled Decision Trees Benchmark","doc":"```elixir\nNx.Defn.default_options(compiler: Nx.Defn.Evaluator)\nNx.default_backend(Nx.BinaryBackend)\n\naccuracies =\n  Enum.reduce(funcs, %{}, fn {name, pred_fn}, acc ->\n    accuracy =\n      pred_fn.(x_test)\n      |> Nx.argmax(axis: -1)\n      |> then(&Scholar.Metrics.Classification.accuracy(y_test, &1))\n      |> Nx.to_number()\n\n    Map.put(acc, name, accuracy)\n  end)\n```","ref":"compiled_benchmarks.html#compare-accuracies"},{"type":"extras","title":"Iris Classification with Gradient Boosting","doc":"# Iris Classification with Gradient Boosting\n\n```elixir\nMix.install([\n  {:exgboost, \"~> 0.4\"},\n  {:nx, \"~> 0.5\"},\n  {:scidata, \"~> 0.1\"},\n  {:scholar, \"~> 0.1\"}\n])\n```","ref":"iris_classification.html"},{"type":"extras","title":"Data - Iris Classification with Gradient Boosting","doc":"We'll be working with the Iris flower dataset. The Iris dataset consists of features corresponding to measurements of 3 different species of the Iris flower. Overall we have 150 examples, each with 4 featurse and a numeric label mapping to 1 of the 3 species. We can download this dataset using [Scidata](https://github.com/elixir-nx/scidata):\n\n```elixir\n{x, y} = Scidata.Iris.download()\n:ok\n```\n\nScidata doesn't provide train-test splits for Iris. Instead, we'll need to shuffle the original dataset and split manually. We'll save 20% of the dataset for testing:\n\n```elixir\ndata = Enum.zip(x, y) |> Enum.shuffle()\n{train, test} = Enum.split(data, ceil(length(data) * 0.8))\n:ok\n```\n\nEXGBoost requires inputs to be [Nx](https://github.com/elixir-nx/nx) tensors. The conversion for this example is rather easy as we can just wrap both features and labels in a call to `Nx.tensor/1`:\n\n```elixir\n{x_train, y_train} = Enum.unzip(train)\n{x_test, y_test} = Enum.unzip(test)\n\nx_train = Nx.tensor(x_train)\ny_train = Nx.tensor(y_train)\n\nx_test = Nx.tensor(x_test)\ny_test = Nx.tensor(y_test)\n\nx_train\n```\n\n```elixir\ny_train\n```\n\nWe now have both train and test sets consisting of features and labels. Time to train a booster!","ref":"iris_classification.html#data"},{"type":"extras","title":"Training - Iris Classification with Gradient Boosting","doc":"The simplest way to train a booster is using the top-level `EXGBoost.train/2` function. This function expects input features and labels, as well as some optional training configuration parameters.\n\nThis example is a multi-class classification problem with 3 output classes. We need to configure EXGBoost to train this booster as a multi-class classifier by specifying a different training objective. We also need to specify the number of output classes:\n\n```elixir\nbooster =\n  EXGBoost.train(x_train, y_train,\n    num_class: 3,\n    objective: :multi_softprob,\n    num_boost_rounds: 10000,\n    evals: [{x_train, y_train, \"training\"}]\n  )\n```\n\nAnd that's it! Now we can test our booster.","ref":"iris_classification.html#training"},{"type":"extras","title":"Testing - Iris Classification with Gradient Boosting","doc":"To get predictions from a trained booster, we can just call `EXGBoost.predict/2`. You'll notice for this problem that the booster outputs a tensor of shape `{30, 3}` where the 2nd dimension represents output probabilities for each class. We can obtain a discrete prediction for use in our accuracy measurement by computing the `argmax` along the last dimension:\n\n```elixir\npreds = EXGBoost.predict(booster, x_test) |> Nx.argmax(axis: -1)\nScholar.Metrics.Classification.accuracy(y_test, preds)\n```\n\nAnd that's it! We've successfully trained a booster on the Iris dataset with `EXGBoost`.","ref":"iris_classification.html#testing"},{"type":"extras","title":"Prediction Intervals using Quantile Regression","doc":"# Prediction Intervals using Quantile Regression\n\n```elixir\nMix.install([\n  {:exgboost, \"~> 0.4\"},\n  {:explorer, \"~> 0.7\"},\n  {:kino_explorer, \"~> 0.1.8\"},\n  {:kino_vega_lite, \"~> 0.1.8\"},\n  {:nx, \"~> 0.6\"},\n  {:tucan, \"~> 0.3\"}\n])\n```","ref":"quantile_prediction_interval.html"},{"type":"extras","title":"Introduction - Prediction Intervals using Quantile Regression","doc":"This livebook shows how quantile regression can be used to create [prediction intervals](https://en.wikipedia.org/wiki/Prediction_interval). It was inspired by the fantastic example from scikit-learn:\n\nhttps://scikit-learn.org/stable/auto_examples/ensemble/plot_gradient_boosting_quantile.html","ref":"quantile_prediction_interval.html#introduction"},{"type":"extras","title":"Synthetic data - Prediction Intervals using Quantile Regression","doc":"First, let's generate some synthetic data to work with.\nWe'll apply the function $f(x) = x\\sin(x)$ to uniformly sampled random inputs from $x \\in [0, 10]$.\n\n```elixir\n# Generate the data.\nkey = Nx.Random.key(42)\n{x, key} = Nx.Random.uniform(key, 0.0, 10.0, shape: {1000})\ny_expected = x |> Nx.sin() |> Nx.multiply(x)\n:ok\n```\n\nNow let's plot the data. We'll be building a number of plots throughout this Livebook using the `Tucan` library.\n\n```elixir\nTucan.scatter([x: x, y_expected: y_expected], \"x\", \"y_expected\", filled: true)\n|> Tucan.set_width(750)\n```\n\nThen we'll add some random noise to the true output.\n\n```elixir\nsigma = x |> Nx.divide(10) |> Nx.add(0.5)\n\n# Note: log-normal noise was used in the original write-up.\n# Nx doesn't support log-normal yet, so we've just used normal.\n{noise, _key} = Enum.map_reduce(Nx.to_list(sigma), key, &Nx.Random.normal(&2, 0.0, &1 * &1))\nnoise = noise |> Nx.stack() |> Nx.subtract(sigma |> Nx.pow(2) |> Nx.divide(2) |> Nx.exp())\ny = Nx.add(y_expected, noise)\n\nTucan.layers([\n  Tucan.scatter([x: x, y: y], \"x\", \"y\", filled: true, fill_opacity: 0.75),\n  Tucan.lineplot([x: x, y_expected: y_expected], \"x\", \"y_expected\", line_color: \"red\")\n])\n|> Tucan.set_width(750)\n```\n\nLast we split the data into train and test sets.\n\n```elixir\nsplit = 0.8\nshuffle_key = key\n{x_shuffled, _key} = Nx.Random.shuffle(shuffle_key, x)\n{y_shuffled, _key} = Nx.Random.shuffle(shuffle_key, y)\n{x_train, x_test} = Nx.split(x_shuffled, split)\n{y_train, y_test} = Nx.split(y_shuffled, split)\n\n[x_train, x_test, y_train, y_test] |> Enum.map(&Nx.size/1)\n\nTucan.layers([\n  Tucan.scatter([x_train: x_train, y_train: y_train], \"x_train\", \"y_train\", filled: true),\n  Tucan.scatter([x_test: x_test, y_test: y_test], \"x_test\", \"y_test\",\n    filled: true,\n    point_color: \"orange\"\n  )\n])\n|> Tucan.set_width(750)\n```","ref":"quantile_prediction_interval.html#synthetic-data"},{"type":"extras","title":"Prediction intervals - Prediction Intervals using Quantile Regression","doc":"Regression models generally make specific predictions.\nIf you give a regression model an input $x$, it will return a prediction $\\hat{y}$ which it believes to be close to the real output $y$.\nSomething regressions models don't typically give you, however, is a sense of how confident they are in their predictions.\n\nOne way we quantify a model's confidence is with a _prediction interval_.\nA prediction interval is an interval $[\\hat{y}_{\\text{lower}}, \\hat{y}_{\\text{upper}}]$ which a model believes the true $y$ lies in with some probability $p$.\n\nOur goal is to construct a regression model that gives both a prediction and a prediction interval.\nWe'll do so by using quantile regression to train 3 separate models on the same data but with the following parameters:\n\n* $\\alpha = 0.05$ (5th percentile)\n* $\\alpha = 0.50$ (50th percentile -- median)\n* $\\alpha = 0.95$ (95th percentile)\n\nThe model trained with $\\alpha = 0.50$ produces a estimate of the median.\nThis will be our actual prediction.\n\nThe models trained with $\\alpha = 0.05$ and $\\alpha = 0.95$ will act as our $\\hat{y}_{\\text{lower}}$ and $\\hat{y}_{\\text{upper}}$, resp.\nTogether, they'll provide a $90\\%$ prediction interval ($95\\% - 5\\% = 90\\%$).\n\nTypically, the $\\alpha = 0.50$ estimate will lie within the prediction interval.\nThis is not guaranteed, however.\nSee the discussion at the end.\n\n```elixir\nopts = [\n  # The default is `max_depth: 6`. It led to a complex model, so I've lowered it.\n  max_depth: 4,\n  # This is how you specify to EXGBoost that it should perform regression.\n  objective: :reg_quantileerror,\n  # This is method generally faster than `:exact`.\n  tree_method: :hist,\n  # The output isn't necessary for our purposes.\n  verbose_eval: false\n]\n\nmodel = %{\n  p05: EXGBoost.train(x_train, y_train, Keyword.put(opts, :quantile_alpha, 0.05)),\n  p50: EXGBoost.train(x_train, y_train, Keyword.put(opts, :quantile_alpha, 0.50)),\n  p95: EXGBoost.train(x_train, y_train, Keyword.put(opts, :quantile_alpha, 0.95))\n}\n\n:ok\n```\n\nNow we'll plot our model against a validation set (just another $1,000$ points randomly sampled from $[0, 10]$) to get a sense of its performance.\n\nWe'll also overlay the test data.\nRemember, the model hasn't seen this data.\nSo if the model captures the test data well, we've built a reasonably general model.\n\n```elixir\n{x_val, key} = Nx.Random.uniform(key, 0.0, 10.0, shape: {1000})\n\ny_val_p05 = EXGBoost.predict(model.p05, x_val)\ny_val_p50 = EXGBoost.predict(model.p50, x_val)\ny_val_p95 = EXGBoost.predict(model.p95, x_val)\n\nplot_data = [x: x_val, p05: y_val_p05, p50: y_val_p50, p95: y_val_p95]\n\nTucan.layers([\n  Tucan.step(plot_data, \"x\", \"p05\", line_color: \"black\"),\n  Tucan.step(plot_data, \"x\", \"p50\", line_color: \"blue\"),\n  Tucan.step(plot_data, \"x\", \"p95\", line_color: \"black\"),\n  Tucan.scatter([x_test: x_test, y_test: y_test], \"x_test\", \"y_test\",\n    point_color: \"orange\",\n    fill_opacity: 0.75,\n    filled: true\n  )\n])\n|> Tucan.set_width(750)\n|> Tucan.set_height(375)\n```\n\nNot bad!\nIt certainly has the rough shape we want:\n\n* The median (blue) generally lies in the \"middle\" of the test data.\n* And the prediction interval (the space between the two black lines) contains most of the test data (orange).\n\nBut we can do better.\nFor example, notice how the the prediction interval tends to remain flat across the highly concave parts of the sinusoid.\nThat doesn't seem quite right.\n\nHowever, first, we need to quantify what we mean by \"better\".","ref":"quantile_prediction_interval.html#prediction-intervals"},{"type":"extras","title":"Metrics: Interval width - Prediction Intervals using Quantile Regression","doc":"An issue with our initial model is that its prediction intervals are too wide (or tall if you like, since the width of the interval appears vertically).\nWe generally want our prediction intervals to be as narrow as possible.\n\nWe can build a simple metric for the width of the prediction interval -- the average of all the widths:\n\n```elixir\ndefmodule Metric.Width do\n  import Nx.Defn\n\n  def calc(model_lo, model_hi, x) do\n    y_lo = EXGBoost.predict(model_lo, x)\n    y_hi = EXGBoost.predict(model_hi, x)\n\n    mean(y_lo, y_hi)\n    |> Nx.to_number()\n  end\n\n  defn(mean(y_lo, y_hi), do: Nx.mean(y_hi - y_lo))\nend\n\n[\n  train: Metric.Width.calc(model.p05, model.p95, x_train),\n  test: Metric.Width.calc(model.p05, model.p95, x_test)\n]\n```\n\nThese numbers aren't particularly interpretable at the moment, but we want them to be as low as possible in the improved model.\n\nHowever, we don't want them _too_ small, or we won't capture the correct percentage of the data.","ref":"quantile_prediction_interval.html#metrics-interval-width"},{"type":"extras","title":"Metrics: Coverage - Prediction Intervals using Quantile Regression","doc":"In addition to having narrow prediction intervals, another desirable property of our model is to produce what we'll refer to as \"well-calibrated\" prediction intervals.\n\nWe trained $5\\%$ and $95\\%$ sub-models to (hopefully) produce an overall 90% prediction interval.\nWe should expect, then, that $\\approx 90\\%$ of the data should lie in that interval. If that's the case, then we can call our overall model well-calibrated.\n\nWe can emprically check our model's calibration by calculating its \"coverage\", i.e. how much of the data lies in the prediction interval:\n\n```elixir\ndefmodule Metric.Coverage do\n  import Nx.Defn\n\n  def calc(model_lo, model_hi, x, y) do\n    y_lo = EXGBoost.predict(model_lo, x)\n    y_hi = EXGBoost.predict(model_hi, x)\n\n    Nx.to_number(fraction(y, y_lo, y_hi))\n  end\n\n  defn fraction(y, y_lo, y_hi) do\n    Nx.mean(Nx.logical_and(y >= y_lo, y <= y_hi))\n  end\nend\n\n[\n  train: Metric.Coverage.calc(model.p05, model.p95, x_train, y_train),\n  test: Metric.Coverage.calc(model.p05, model.p95, x_test, y_test)\n]\n```\n\nThis is pretty good, though we've captured a bit too much of the both the test and training sets.\nThis seems to corroborate our visual observation that the prediction interval doesn't hug the sinusoid as tightly as we might hope.\n\nNow we need to train a model that has balances both these metrics.","ref":"quantile_prediction_interval.html#metrics-coverage"},{"type":"extras","title":"Improved model: combining width and coverage - Prediction Intervals using Quantile Regression","doc":"We want to build a model that has both narrow prediction intervals and good coverage.\nUnfortunately, our lower and upper bounds are trained independently.\nThis is a problem because the width and coverage metrics are functions of both bounds.\n\nTo work around this, we'll perform hyper-parameter tuning.\nBasically, we're gonna train many models using the same quantile regression as before, but we'll chose the best one based on a metric that `EXGBoost` doesn't know about directly.\n\nFor this example, since the size of the data is relatively small, we'll do a simple, brute-force search of the parameter space.\nWe'll be varying the following parameters:\n\n* `alpha` (Default: 0)\n  * $L_1$ regularization term on weights. Increasing this value will make model more conservative.\n* `eta` (Default: 0.3)\n  * Step size shrinkage used in update to prevents overfitting. After each boosting step, we can directly get the weights of new features, and `eta` shrinks the feature weights to make the boosting process more conservative.\n* `lambda` (Default: 0)\n  * $L_2$ regularization term on weights. Increasing this value will make model more conservative.\n* `max_depth` (Default: 6)\n  * Maximum depth of a tree. Increasing this value will make the model more complex and more likely to overfit.\n\nThere are more parameters we could tune, but these suffice for demonstration purposes.\n\nThis brute-force approach will train hundreds of models. It runs in about 45 seconds for me.\n\n```elixir\ndefmodule Metric.Combined do\n  def calc(model_lo, model_hi, x, y) do\n    y_lo = EXGBoost.predict(model_lo, x)\n    y_hi = EXGBoost.predict(model_hi, x)\n\n    coverage = Metric.Coverage.fraction(y, y_lo, y_hi) |> Nx.to_number()\n    coverage_score = abs(0.90 - coverage)\n\n    width_score = Metric.Width.mean(y_lo, y_hi) |> Nx.to_number()\n\n    # Combine both scores with magic weights: the \"dark art\" of data engineering.\n    2 * coverage_score + width_score / 4\n  end\nend\n\nmodel_opts =\n  [\n    alpha: 1..3,\n    eta: -2..-5,\n    lambda: 1..3,\n    max_depth: 1..3\n  ]\n  |> Enum.map(fn {k, v} -> {k, Enum.map(v, &(2 ** &1))} end)\n\n# Since we're training so many models, we'll implement early stopping.\nopts =\n  Keyword.merge(opts,\n    early_stopping_rounds: 2,\n    eval_metric: [:rmse],\n    evals: [{x_test, y_test, \"test\"}],\n    num_boost_rounds: 64\n  )\n\nbest_result =\n  for alpha <- model_opts[:alpha],\n      eta <- model_opts[:eta],\n      lambda <- model_opts[:lambda],\n      max_depth <- model_opts[:max_depth],\n      reduce: %{score: 1_000} do\n    acc ->\n      params = [\n        alpha: alpha,\n        eta: eta,\n        lambda: lambda,\n        max_depth: max_depth\n      ]\n\n      train_opts = Keyword.merge(opts, params)\n\n      model_lo = EXGBoost.train(x_train, y_train, Keyword.put(train_opts, :quantile_alpha, 0.05))\n      model_hi = EXGBoost.train(x_train, y_train, Keyword.put(train_opts, :quantile_alpha, 0.95))\n\n      score = Metric.Combined.calc(model_lo, model_hi, x_test, y_test)\n\n      if score   Tucan.set_width(750)\n|> Tucan.set_height(375)\n```\n\nThat seems much better!\nAt least visually, it looks like our new model has narrower prediction intervals.\n\nBut did the model _actually_ improve on the metrics we specified?\nLet's check.\n\n```elixir\nrequire Explorer.DataFrame, as: DF\n\n[\n  %{\n    model: \"old\",\n    train_coverage: Metric.Coverage.calc(model.p05, model.p95, x_train, y_train),\n    test_coverage: Metric.Coverage.calc(model.p05, model.p95, x_test, y_test),\n    train_width: Metric.Width.calc(model.p05, model.p95, x_train),\n    test_width: Metric.Width.calc(model.p05, model.p95, x_test)\n  },\n  %{\n    model: \"new\",\n    train_coverage: Metric.Coverage.calc(best_model_lo, best_model_hi, x_train, y_train),\n    test_coverage: Metric.Coverage.calc(best_model_lo, best_model_hi, x_test, y_test),\n    train_width: Metric.Width.calc(best_model_lo, best_model_hi, x_train),\n    test_width: Metric.Width.calc(best_model_lo, best_model_hi, x_test)\n  }\n]\n|> DF.new()\n```\n\nThe train coverage and width metrics both improved. Train coverage is now closer to $0.90$, and the average width was reduced by $\\frac{|5.57 - 3.50|}{5.57} = 37.2\\%$.\n\nFor test, the coverage improved nearly as much.\nBut the coverage remained about the same distance from $0.90$ as before, though now the model under-covers instead of over-covering.\nThis is probably an acceptable trade-off.\nThough if we wanted further improvements, we could always do more tuning.","ref":"quantile_prediction_interval.html#improved-model-combining-width-and-coverage"},{"type":"extras","title":"Discussion - Prediction Intervals using Quantile Regression","doc":"The focus of this example was the prediction interval.\nWe were able to create a model that would not only predict an output, but also quantify how close it thought its prediction was.\n\nFor example:\n\n```elixir\nx_comp = Nx.tensor([1.0, 8.0])\n\ny_comp_p05 = EXGBoost.predict(best_model_lo, x_comp)\ny_comp_p50 = EXGBoost.predict(model.p50, x_comp)\ny_comp_p95 = EXGBoost.predict(best_model_hi, x_comp)\nwidth = Nx.subtract(y_comp_p95, y_comp_p05)\n\nDF.new(\n  x: x_comp |> Nx.to_list() |> Enum.map(&Float.round(&1, 2)),\n  y_hat: y_comp_p50 |> Nx.to_list() |> Enum.map(&Float.round(&1, 2)),\n  interval_lo: y_comp_p05 |> Nx.to_list() |> Enum.map(&Float.round(&1, 2)),\n  interval_hi: y_comp_p95 |> Nx.to_list() |> Enum.map(&Float.round(&1, 2)),\n  width: width |> Nx.to_list() |> Enum.map(&Float.round(&1, 2))\n)\n```\n\nIn a vacuum, we might expect that the model was equally as confident in its two predictions:\n\n* $1 \\mapsto -0.59$\n* $8 \\mapsto 4.58$\n\nBut with the additional context of a prediction interval, we can see that our model is much more confident in the former than the latter:\n\n* $1 \\mapsto -0.59 \\in [-0.89, 0.07]$ (width: $0.97$)\n* $8 \\mapsto  4.58 \\in [ 1.89, 7.40]$ (width: $5.51$)\n\nThat additional context can be very helpful for anyone who wishes to make a decision based off a prediction.\nHowever, it's worth discussing the limitations of this model.","ref":"quantile_prediction_interval.html#discussion"},{"type":"extras","title":"Discussion: Quantile crossing - Prediction Intervals using Quantile Regression","doc":"The fact that the sub-parts of our model were trained independently has already caused some issues.\nBecause `EXGBoost` had no knowledge of the metrics we were interested in, we had to train multiple models to find a pair that had the properties we wanted.\n\nSimilarly, quantile regression models trained independently as we've done are subject to _quantile crossing_.\n\nBriefly, there's no guarantee that the predictions from the models we've trained will have the right order.\nE.g. the $\\alpha = 0.05$ model may sometimes be higher than the $\\alpha = 0.95$.\nThis ought to rare in a well-trained model.\nBut especially when the prediction interval is narrow, crossing can occur.\n\nFor the same reason, the actual prediction may sometimes fall outside the prediction interval.\nAgain, it ought to be rare if the model was trained well.\nBut it's a limitation worth knowing about.","ref":"quantile_prediction_interval.html#discussion-quantile-crossing"},{"type":"extras","title":"Discussion: Pinball error - Prediction Intervals using Quantile Regression","doc":"Something else we didn't discuss is how `EXGBoost` trains quantile regression in the first place.\nWe discuss it now for completeness and to provide a warning about early stopping.\n\nWith most regression tasks, `EXGBoost` is optimizing for a familiar metric such as `mean_absolute_error`:\n\n$$\n\\texttt{mean\\_absolute\\_error} = \\frac{1}{n} \\sum_{i=1}^{n} |y_i - \\hat{y}_i|\n$$\n\nBut the more familiar metrics don't take into account the $\\alpha$ that we want to train.\nAs such, when `objective: reg_quantileerror` is provided, `EXGBoost` optimizes for a metric called the `mean_quantile_error` / `mean_pinball_error`:\n\n$$\n\\texttt{mean\\_pinball\\_error}(\\alpha) =\n  \\frac{1}{n} \\sum_{i=1}^{n} \\texttt{pinball}(\\hat{y}_i, y_i, \\alpha)\n$$\n\nwhere\n\n$$\n\\texttt{pinball}(\\hat{y}_i, y_i, \\alpha) =\n\\begin{cases}\n|\\hat{y}_i - y_i| \\cdot (1 - \\alpha) &\\text{if ~ } \\hat{y}_i \\leq y_i\\\\\n|\\hat{y}_i - y_i| \\cdot       \\alpha &\\text{if ~ } \\hat{y}_i \\gt  y_i\n\\end{cases}\n$$\n\nEssentially, the error should be $0$ if the the prediction matches the true value ($\\hat{y}_i = y_i$).\nBut the penalty for being incorrect is now a function of the quantile $\\alpha$.\n\nTake $\\alpha = 0.95$ as an example.\nA model trained for $\\alpha = 0.95$ should predict values that are above $95\\%$ of the true values.\nSo we want high penalties for any prediction below $95\\%$, and moderate penalties for being above.\n\n(Sidenote: if $\\alpha = 0.5$, the `mean_pinball_error` is equivalent to the `mean_absolute_error` up to a constant factor of $0.5$).\n\nNow let's write our own `mean_pinball_error`:\n\n```elixir\ndefmodule Pinball do\n  import Nx.Defn\n\n  defn mean_error(y_pred, y_true, alpha) do\n    dy = y_true - y_pred\n    # if dy < 0, do: alpha, else: alpha - 1\n    coeff = alpha + (dy >= 0) - 1\n    error = coeff * dy\n    Nx.mean(error)\n  end\nend\n```\n\nThen let's score our model on the test data using this metric:\n\n```elixir\ny_pinball_p05 = EXGBoost.predict(best_model_lo, x_test)\ny_pinball_p50 = EXGBoost.predict(model.p50, x_test)\ny_pinball_p95 = EXGBoost.predict(best_model_hi, x_test)\n\ny_preds = [y_pinball_p05, y_pinball_p50, y_pinball_p95]\nalpha_strings = [\"05\", \"50\", \"95\"]\n\nalpha_strings\n|> Map.new(fn alpha_string ->\n  alpha = String.to_float(\"0.#{alpha_string}\")\n\n  y_pred =\n    y_preds\n    |> Enum.map(&Pinball.mean_error(&1, y_test, alpha))\n    |> Enum.map(&Nx.to_number/1)\n    |> Enum.map(&Float.round(&1, 2))\n\n  {\"p_#{alpha_string} metric\", y_pred}\nend)\n|> Map.put(\"model\", [\"q_05\", \"q_50\", \"q_95\"])\n|> Explorer.DataFrame.new()\n```\n\nEach of the 3 models performed better than the other 2 when the metric matched what quantile it was trained for.\nWe can see this in the table above where, for each column, the lowest score lies on the diagonal.\n\nWe discuss the pinball error because it's the metric that should be used for early stopping.\nHowever, `EXGBoost` (not `XGBoost` under the hood) currently does not expose expose this metric through their API.\n\nThis isn't terribly surprising as quantile regression is [relatively new](https://github.com/dmlc/xgboost/pull/8750).\nHowever, if one wished to perform early stopping correctly, they'd need a custom metric set to the `Pinball.mean_error` function provided here (or equivalent).\nThis is left as an exercise to the reader :)","ref":"quantile_prediction_interval.html#discussion-pinball-error"},{"type":"extras","title":"Plotting in EXGBoost","doc":"# Plotting in EXGBoost\n\n```elixir\nMix.install([\n  {:exgboost, \"~> 0.5\"},\n  {:scidata, \"~> 0.1\"},\n  {:kino_vega_lite, \"~> 0.1\"}\n])\n\n# This assumed you launch this livebook from its location in the exgboost/notebooks folder\n```","ref":"plotting.html"},{"type":"extras","title":"Introduction - Plotting in EXGBoost","doc":"Much of the utility from decision trees come from their intuitiveness and ability to inform dcisions outside of the confines of a black-box model. A decision tree can be easily translated to a series of actions that can be taken on behalf of the stakeholder to achieve the desired outcome. This makes them especially useful in business decisions, where people might still want to have the final say but be as informed as possible. Additionally, tabular data is still quite popular in the business domain, which conforms to the required input for decision trees.\n\nDecision trees can be used for both regression and classification tasks, but classification tends to be what is most associated with decision trees.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nThis notebook will go over some of the details of the `EXGBoost.Plotting` module, including using preconfiged styles, custom styling, as well as customizing the entire vidualization.","ref":"plotting.html#introduction"},{"type":"extras","title":"Plotting APIs - Plotting in EXGBoost","doc":"There are 2 main APIs exposed to control plotting in `EXGBoost`:\n\n- Top-level API (`EXGBoost.plot_tree/2`)\n\n  - Using predefined styles\n  - Defining custom styles\n  - Mix of the first 2\n\n- `EXBoost.Plotting` module API\n\n  - Use the Vega `data` spec defined in `EXGBoost.Plotting.get_data_spec/2`\n  - Define your own Vega spec using the data from either `EXGBoost.Plotting.to_tabular/1` or some other means\n\n  We will walk through each of these in detail.\n\nRegardless of which API you choose to use, it is helpful to understand how the plotting module works (althought the higher-level API you choose to work with the less important it becomes).","ref":"plotting.html#plotting-apis"},{"type":"extras","title":"Implementation Details - Plotting in EXGBoost","doc":"The plotting functionality provided in `EXGBoost` is powered by the [Vega](https://vega.github.io/vega/) JavaScript library and the Elixir [`VegaLite`](https://hexdocs.pm/vega_lite/VegaLite.html) library which provides the piping to interop with the JavaScript libraries. **We do not actually much use the Elixir API provided by the Elixir VegaLite library. It is mainly used for the purposes of rendering.**\n\nVega is a plotting library built on top of the very powerful [D3](https://d3js.org/) JavaScript library. Vega visualizations are defined according to the respective JSON Schema specification. Vega-Lite offers a [reduced schema](https://vega.github.io/schema/vega-lite/v5.json) compared to the [full Vega spec](https://vega.github.io/schema/vega/v5.json). `EXGBoost.Plotting` leverages several transforms which are not available in the reduced Vega-Lite schema, which is the reason for targeting the lower-level API.\n\nFor these reasons, unfortunately we could not just implement plotting for `EXGBoost` as a composable Vega-Lite pipeline. This makes working synamically with the spec a bit more unwieldly, but much care was taken to still make the high-level plotting API extensible, and if needed you can go straight to defining your own JSON spec.","ref":"plotting.html#implementation-details"},{"type":"extras","title":"Setup Data - Plotting in EXGBoost","doc":"We will still be using the Iris dataset for this notebook, but if you want more details about the process of training and evaluating a model please check out the `Iris Classification with Gradient Boosting` notebook.\n\nSo let's proceed by setting up the Iris dataset.\n\n```elixir\n{x, y} = Scidata.Iris.download()\ndata = Enum.zip(x, y) |> Enum.shuffle()\n{train, test} = Enum.split(data, ceil(length(data) * 0.8))\n{x_train, y_train} = Enum.unzip(train)\n{x_test, y_test} = Enum.unzip(test)\n\nx_train = Nx.tensor(x_train)\ny_train = Nx.tensor(y_train)\n\nx_test = Nx.tensor(x_test)\ny_test = Nx.tensor(y_test)\n```","ref":"plotting.html#setup-data"},{"type":"extras","title":"Train Your Booster - Plotting in EXGBoost","doc":"Now go ahead and train your booster. We will use `early_stopping_rounds: 1` because we're not interested in the accuracy of the booster for this demonstration (_Note that we need to set `evals` to use early stopping_).\n\nYou will notice that `EXGBoost` also provides an implementation for `Kino.Render` so that `EXGBoost.Booster`s are rendered as a plot by default.\n\n```elixir\nbooster =\n  EXGBoost.train(\n    x_train,\n    y_train,\n    num_class: 3,\n    objective: :multi_softprob,\n    num_boost_rounds: 10,\n    evals: [{x_train, y_train, \"training\"}],\n    verbose_eval: false,\n    early_stopping_rounds: 1\n  )\n```\n\nYou'll notice that the plot doesn't display any labels to the features in the splits, and instead only shows features labelled as \"f2\" etc. If you provide feature labels during training, your plot will show the splits using the feature labels.\n\n```elixir\nbooster =\n  EXGBoost.train(x_train, y_train,\n    num_class: 3,\n    objective: :multi_softprob,\n    num_boost_rounds: 10,\n    evals: [{x_train, y_train, \"training\"}],\n    verbose_eval: false,\n    feature_name: [\"sepal length\", \"sepal width\", \"petal length\", \"petal width\"],\n    early_stopping_rounds: 1\n  )\n```","ref":"plotting.html#train-your-booster"},{"type":"extras","title":"Top-Level API - Plotting in EXGBoost","doc":"`EXGBoost.plot_tree/2` is the quickest way to customize the output of the plot.\n\nThis API uses [Vega `Mark`s](https://vega.github.io/vega/docs/marks/) to describe the plot. Each of the following `Mark` options accepts any of the valid keys from their respective `Mark` type as described in the Vega documentation.\n\n**Please note that these are passed as a `Keyword`, and as such the keys must be atoms rather than strings as the Vega docs show. Valid options for this API are `camel_cased` atoms as opposed to the `pascalCased` strings the Vega docs describe, so if you wish to pass `\"fontSize\"` as the Vega docs show, you would instead pass it as `font_size:` in this API.**\n\nThe plot is composed of the following parts:\n\n- Top-level keys: Options controlling parts of the plot outside of direct control of a `Mark`, such as `:padding`, `:autosize`, etc. Accepts any Vega top-level [top-level key](https://vega.github.io/vega/docs/specification/) in addition to several specific to this API (scuh as `:style` and `:depth`).\n- `:leaves`: `Mark` specifying the leaf nodes of the tree\n  - `:text`: [Text Mark](https://vega.github.io/vega/docs/marks/text/)\n  - `:rect`: [Rect Mark](https://vega.github.io/vega/docs/marks/rect/)\n- `:splits` `Mark` specifying the split (or inner / decision) nodes of the tree\n  - `:text`: [Text Mark](https://vega.github.io/vega/docs/marks/text/)\n  - `:rect`: [Rect Mark](https://vega.github.io/vega/docs/marks/rect/)\n  - `:children`: [Text Mark](https://vega.github.io/vega/docs/marks/text/) for the child count\n- `:yes`\n  - `:path`: [Path Mark](https://vega.github.io/vega/docs/marks/path/)\n  - `:text`: [Text Mark](https://vega.github.io/vega/docs/marks/text/)\n- `:no`\n  - `:path`: [Path Mark](https://vega.github.io/vega/docs/marks/path/)\n  - `:text`: [Text Mark](https://vega.github.io/vega/docs/marks/text/)\n\n`EXGBoost.plot_tree/2` defaults to outputting a `VegaLite` struct. If you pass the `:path` option it will save to a file instead.\n\nIf you want to add any marks to the underlying plot you will have to use the lower-level `EXGBoost.Plotting` API, as the top-level API is only capable of customizing these marks.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\n#","ref":"plotting.html#top-level-api"},{"type":"extras","title":"Top-Level Keys - Plotting in EXGBoost","doc":"<!-- livebook:{\"break_markdown\":true} -->\n\n`EXGBoost` supports changing the direction of the plots through the `:rankdir` option. Avaiable directions are `[:tb, :bt, :lr, :rl]`, with top-to-bottom (`:tb`) being the default.\n\n```elixir\nEXGBoost.plot_tree(booster, rankdir: :bt)\n```\n\nBy default, plotting only shows one (the first) tree, but seeing as a `Booster` is really an ensemble of trees you can choose which tree to plot through the `:index` option, or set to `nil` to have a dropdown box to select the tree.\n\n```elixir\nEXGBoost.plot_tree(booster, rankdir: :lr, index: nil)\n```\n\nYou'll also notice that the plot is interactive, with support for scrolling, zooming, and collapsing sections of the tree. If you click on a split node you will toggle the visibility of its descendents, and the rest of the tree will fill the canvas.\n\nYou can also use the `:depth` option to programatically set the max depth to display in the tree:\n\n```elixir\nEXGBoost.plot_tree(booster, rankdir: :lr, index: 4, depth: 3)\n```\n\nOne way to affect the canvas size is by controlling the padding.\n\nYou can add padding to all side by specifying an integer for the `:padding` option\n\n```elixir\nEXGBoost.plot_tree(booster, rankdir: :rl, index: 4, depth: 3, padding: 50)\n```\n\nOr specify padding for each side:\n\n```elixir\nEXGBoost.plot_tree(booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  padding: [top: 5, bottom: 25, left: 50, right: 10]\n)\n```\n\nYou can also specify the canvas size using the `:width` and `:height` options:\n\n```elixir\nEXGBoost.plot_tree(booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  width: 500,\n  height: 500\n)\n```\n\nBut do note that changing the padding of a canvas does change the size, even if you specify the size using `:height` and `:width`\n\n```elixir\nEXGBoost.plot_tree(booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  width: 500,\n  height: 500,\n  padding: 10\n)\n```\n\nYou can change the dimensions of all nodes through the `:node_height` and `:node_width` options:\n\n```elixir\nEXGBoost.plot_tree(booster, rankdir: :lr, index: 4, depth: 3, node_width: 60, node_height: 60)\n```\n\nOr change the space between nodes using the `:space_between` option.\n\n**Note that the size of the accompanying nodes and/or text will change to accomodate the new `:space_between` option while trying to maintain the canvas size.**\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  space_between: [nodes: 200]\n)\n```\n\nSo if you want to add the space between while not changing the size of the nodes you might need to manually adjust the canvas size:\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  space_between: [nodes: 200],\n  height: 800\n)\n```\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  space_between: [levels: 200]\n)\n```\n\n#","ref":"plotting.html#top-level-keys"},{"type":"extras","title":"Mark Options - Plotting in EXGBoost","doc":"The options controlling the appearance of individual marks all conform to a similar API. You can refer to the options and pre-defined defaults for a subset of the allowed options, but you can also pass other options so long as they are allowed by the Vega Mark spec (as defined [here](#cell-y5oxrrri4daa6xt5))\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  rankdir: :bt,\n  index: 4,\n  depth: 3,\n  space_between: [levels: 200],\n  yes: [\n    text: [font_size: 18, fill: :teal]\n  ],\n  no: [\n    text: [font_size: 20]\n  ],\n  node_width: 100\n)\n```\n\nMost marks accept an `:opacity` option that you can use to effectively hide the mark:\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  rankdir: :lr,\n  index: 4,\n  depth: 3,\n  splits: [\n    text: [opacity: 0],\n    rect: [opacity: 0],\n    children: [opacity: 1]\n  ]\n)\n```\n\nAnd `text` marks accept normal text options such as `:fill`, `:font_size`, and `:font`:\n\n```elixir\nEXGBoost.plot_tree(\n  booster,\n  node_width: 250,\n  splits: [\n    text: [font: \"Helvetica Neue\", font_size: 20, fill: \"orange\"]\n  ],\n  space_between: [levels: 20]\n)\n```\n\n#","ref":"plotting.html#mark-options"},{"type":"extras","title":"Styles - Plotting in EXGBoost","doc":"There are a set of provided pre-configured settings for the top-level API that you may optionally use. You can refer to the `EXGBoost.Plottings.Styles` docs to see a gallery of each style in action. You can specify a style with the `:style` option in `EXGBoost.plot_tree/2`.\n\nYou can still specify custom settings along with using a style. Most styles only specify a subset of the total possible settings, but you are free to specify any other allowed keys and they will be merged with the style. Any options passed explicitly to the option **does** take precedence over the style options.\n\nFor example, let's look at the `:solarized_dark` style:\n\n```elixir\nEXGBoost.Plotting.solarized_dark() |> Keyword.take([:background, :height]) |> IO.inspect()\nEXGBoost.plot_tree(booster, style: :solarized_dark)\n```\n\nYou can see that it defines a background color of `#002b36` but does not restrict what the height must be.\n\n```elixir\nEXGBoost.plot_tree(booster, style: :solarized_dark, background: \"white\", height: 200)\n```\n\nWe specified both `:background` and `:height` here, and the background specified in the option supercedes the one from the style.\n\nYou can also always get the style specification as a `Keyword` which can be passed to `EXGBoost.plot_tree/2` manually, making any needed changes yourself, like so:\n\n```elixir\ncustom_style = EXGBoost.Plotting.solarized_dark() |> Keyword.put(:background, \"white\")\nEXGBoost.plot_tree(booster, style: custom_style)\n```\n\nYou can also programatically check which styles are available:\n\n```elixir\nEXGBoost.Plotting.get_styles()\n```\n\n#","ref":"plotting.html#styles"},{"type":"extras","title":"Configuration - Plotting in EXGBoost","doc":"You can also set defaults for the top-level API using an `Application` configuration for `EXGBoost` under the `:plotting` key. Since the defaults are collected from your configuration file at compile-time, anything you set during runtime, even if you set it to the Application environment, will not be registered as defaults.\n\nFor example, if you just want to change the default pre-configured style you can do:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\nMix.install([\n  {:exgboost, path: Path.join(__DIR__, \"..\"), env: :dev},\n],\n  config:\n  [\n    exgboost: [\n      plotting: [\n          style: :solarized_dark,\n        ]]\n      ],\n  lockfile: :exgboost)\n```\n\nYou can also make one-off changes to any of the settings with this method. In effect, this turns into a default custom style. **Just make sure to set `style: nil` to ensure that the `style` option doesn't supercede any of your settings.** Here's an example of that:\n\n<!-- livebook:{\"force_markdown\":true} -->\n\n```elixir\n  default_style =\n  [\n    style: nil,\n    background: \"#3f3f3f\",\n    leaves: [\n      # Foreground\n      text: [fill: \"#dcdccc\", font_size: 12, font_style: \"normal\", font_weight: \"normal\"],\n      # Comment\n      rect: [fill: \"#7f9f7f\", stroke: \"#7f9f7f\"]\n    ],\n    splits: [\n      # Foreground\n      text: [fill: \"#dcdccc\", font_size: 12, font_style: \"normal\", font_weight: \"bold\"],\n      # Comment\n      rect: [fill: \"#7f9f7f\", stroke: \"#7f9f7f\"],\n      # Selection\n      children: [fill: \"#2b2b2b\", stroke: \"#2b2b2b\"]\n    ],\n    yes: [\n      # Green\n      text: [fill: \"#7f9f7f\"],\n      # Selection\n      path: [stroke: \"#2b2b2b\"]\n    ],\n    no: [\n      # Red\n      text: [fill: \"#cc9393\"],\n      # Selection\n      path: [stroke: \"#2b2b2b\"]\n    ]\n  ]\n\nMix.install([\n  {:exgboost, path: Path.join(__DIR__, \"..\"), env: :dev},\n],\nconfig:\n  [\n    exgboost: [\n      plotting: default_style,\n    ]\n  ]\n)\n```\n\n**NOTE: When you specify a parameter in the configuration, it is merged with the defaults which is different from runtime behavior.**\n\nAt any point, you can check what your default settings are by using `EXGBoost.Plotting.get_defaults/0`\n\n```elixir\nEXGBoost.Plotting.get_defaults()\n```","ref":"plotting.html#configuration"},{"type":"extras","title":"Low-Level API - Plotting in EXGBoost","doc":"If you find yourself needing more granular control over your plots, you can reach towards the `EXGBoost.Plotting` module. This module houses the `EXGBoost.Plotting.plot/2` function, which is what is used under the hood from the `EXGBoost.plot_tree/2` top-level API. This module also has the `get_data_spec/2` function, as well as the `to_tabular/1` function, both of which can be used to specify your own Vega specification. Lastly, the module also houses all of the pre-configured styles, which are 0-arity functions which output the `Keyword`s containing their respective style's options that can be passed to the plotting APIs.\n\nLet's briefly go over the `to_tabular/1` and `get_data_spec/2` functions:\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nThe `to_tabular/1` function is used to convert a `Booster`, which is formatted as a tree structure, to a tabular format which can be ingested specifically by the [Vega Stratify transform](https://vega.github.io/vega/docs/transforms/stratify/). It returns a list of \"nodes\", which are just `Map`s with info about each node in the tree.\n\n```elixir\nEXGBoost.Plotting.to_tabular(booster) |> hd\n```\n\nYou can use this function if you want to have complete control over the visualization, and just want a bit of a head start with respect to data transformation for converting the `Booster` into a more digestible format.\n\n<!-- livebook:{\"break_markdown\":true} -->\n\nThe `get_data_source/2` function is used if you want to use the provided [Vega data specification](https://vega.github.io/vega/docs/data/). This is for those who want to only focus on implementing your own [Vega Marks](https://vega.github.io/vega/docs/marks/), and want to leverage the data transformation pipeline that powers the top-level API.\n\nThe data transformation used is the following pipeline:\n\n`to_tabular/1` -> [Filter](https://vega.github.io/vega/docs/transforms/filter/) (by tree index) -> [Stratify](https://vega.github.io/vega/docs/transforms/stratify/) -> [Tree](https://vega.github.io/vega/docs/transforms/tree/)\n\n```elixir\nEXGBoost.Plotting.get_data_spec(booster, rankdir: :bt)\n```\n\nThe Vega fields which are not included with `get_data_spec/2` and are included in `plot/2` are:\n\n- [Marks](https://vega.github.io/vega/docs/marks/)\n- [Scales](https://vega.github.io/vega/docs/scales/)\n- [Signals](https://vega.github.io/vega/docs/signals/)\n\nYou can make a completely valid plot using only the Data from `get_data_specs/2` and adding the marks you need.","ref":"plotting.html#low-level-api"}],"content_type":"text/markdown"}